"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import waCommon.WACommon_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ConsumerApplication(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Payload(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CONTENT_FIELD_NUMBER: builtins.int
        APPLICATIONDATA_FIELD_NUMBER: builtins.int
        SIGNAL_FIELD_NUMBER: builtins.int
        SUBPROTOCOL_FIELD_NUMBER: builtins.int
        @property
        def content(self) -> global___ConsumerApplication.Content: ...
        @property
        def applicationData(self) -> global___ConsumerApplication.ApplicationData: ...
        @property
        def signal(self) -> global___ConsumerApplication.Signal: ...
        @property
        def subProtocol(self) -> global___ConsumerApplication.SubProtocolPayload: ...
        def __init__(
            self,
            *,
            content: global___ConsumerApplication.Content | None = ...,
            applicationData: global___ConsumerApplication.ApplicationData | None = ...,
            signal: global___ConsumerApplication.Signal | None = ...,
            subProtocol: global___ConsumerApplication.SubProtocolPayload | None = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing.Literal[
                "applicationData",
                b"applicationData",
                "content",
                b"content",
                "payload",
                b"payload",
                "signal",
                b"signal",
                "subProtocol",
                b"subProtocol",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing.Literal[
                "applicationData",
                b"applicationData",
                "content",
                b"content",
                "payload",
                b"payload",
                "signal",
                b"signal",
                "subProtocol",
                b"subProtocol",
            ],
        ) -> None: ...
        def WhichOneof(
            self, oneof_group: typing.Literal["payload", b"payload"]
        ) -> (
            typing.Literal["content", "applicationData", "signal", "subProtocol"] | None
        ): ...

    @typing.final
    class SubProtocolPayload(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        FUTUREPROOF_FIELD_NUMBER: builtins.int
        futureProof: waCommon.WACommon_pb2.FutureProofBehavior.ValueType
        def __init__(
            self,
            *,
            futureProof: waCommon.WACommon_pb2.FutureProofBehavior.ValueType
            | None = ...,
        ) -> None: ...
        def HasField(
            self, field_name: typing.Literal["futureProof", b"futureProof"]
        ) -> builtins.bool: ...
        def ClearField(
            self, field_name: typing.Literal["futureProof", b"futureProof"]
        ) -> None: ...

    @typing.final
    class Metadata(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _SpecialTextSize:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _SpecialTextSizeEnumTypeWrapper(
            google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
                ConsumerApplication.Metadata._SpecialTextSize.ValueType
            ],
            builtins.type,
        ):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            SMALL: ConsumerApplication.Metadata._SpecialTextSize.ValueType  # 1
            MEDIUM: ConsumerApplication.Metadata._SpecialTextSize.ValueType  # 2
            LARGE: ConsumerApplication.Metadata._SpecialTextSize.ValueType  # 3

        class SpecialTextSize(
            _SpecialTextSize, metaclass=_SpecialTextSizeEnumTypeWrapper
        ): ...
        SMALL: ConsumerApplication.Metadata.SpecialTextSize.ValueType  # 1
        MEDIUM: ConsumerApplication.Metadata.SpecialTextSize.ValueType  # 2
        LARGE: ConsumerApplication.Metadata.SpecialTextSize.ValueType  # 3

        SPECIALTEXTSIZE_FIELD_NUMBER: builtins.int
        specialTextSize: global___ConsumerApplication.Metadata.SpecialTextSize.ValueType
        def __init__(
            self,
            *,
            specialTextSize: global___ConsumerApplication.Metadata.SpecialTextSize.ValueType
            | None = ...,
        ) -> None: ...
        def HasField(
            self, field_name: typing.Literal["specialTextSize", b"specialTextSize"]
        ) -> builtins.bool: ...
        def ClearField(
            self, field_name: typing.Literal["specialTextSize", b"specialTextSize"]
        ) -> None: ...

    @typing.final
    class Signal(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        def __init__(
            self,
        ) -> None: ...

    @typing.final
    class ApplicationData(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        REVOKE_FIELD_NUMBER: builtins.int
        @property
        def revoke(self) -> global___ConsumerApplication.RevokeMessage: ...
        def __init__(
            self,
            *,
            revoke: global___ConsumerApplication.RevokeMessage | None = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing.Literal[
                "applicationContent", b"applicationContent", "revoke", b"revoke"
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing.Literal[
                "applicationContent", b"applicationContent", "revoke", b"revoke"
            ],
        ) -> None: ...
        def WhichOneof(
            self,
            oneof_group: typing.Literal["applicationContent", b"applicationContent"],
        ) -> typing.Literal["revoke"] | None: ...

    @typing.final
    class Content(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        MESSAGETEXT_FIELD_NUMBER: builtins.int
        IMAGEMESSAGE_FIELD_NUMBER: builtins.int
        CONTACTMESSAGE_FIELD_NUMBER: builtins.int
        LOCATIONMESSAGE_FIELD_NUMBER: builtins.int
        EXTENDEDTEXTMESSAGE_FIELD_NUMBER: builtins.int
        STATUSTEXTMESSAGE_FIELD_NUMBER: builtins.int
        DOCUMENTMESSAGE_FIELD_NUMBER: builtins.int
        AUDIOMESSAGE_FIELD_NUMBER: builtins.int
        VIDEOMESSAGE_FIELD_NUMBER: builtins.int
        CONTACTSARRAYMESSAGE_FIELD_NUMBER: builtins.int
        LIVELOCATIONMESSAGE_FIELD_NUMBER: builtins.int
        STICKERMESSAGE_FIELD_NUMBER: builtins.int
        GROUPINVITEMESSAGE_FIELD_NUMBER: builtins.int
        VIEWONCEMESSAGE_FIELD_NUMBER: builtins.int
        REACTIONMESSAGE_FIELD_NUMBER: builtins.int
        POLLCREATIONMESSAGE_FIELD_NUMBER: builtins.int
        POLLUPDATEMESSAGE_FIELD_NUMBER: builtins.int
        EDITMESSAGE_FIELD_NUMBER: builtins.int
        @property
        def messageText(self) -> waCommon.WACommon_pb2.MessageText: ...
        @property
        def imageMessage(self) -> global___ConsumerApplication.ImageMessage: ...
        @property
        def contactMessage(self) -> global___ConsumerApplication.ContactMessage: ...
        @property
        def locationMessage(self) -> global___ConsumerApplication.LocationMessage: ...
        @property
        def extendedTextMessage(
            self,
        ) -> global___ConsumerApplication.ExtendedTextMessage: ...
        @property
        def statusTextMessage(
            self,
        ) -> global___ConsumerApplication.StatusTextMesage: ...
        @property
        def documentMessage(self) -> global___ConsumerApplication.DocumentMessage: ...
        @property
        def audioMessage(self) -> global___ConsumerApplication.AudioMessage: ...
        @property
        def videoMessage(self) -> global___ConsumerApplication.VideoMessage: ...
        @property
        def contactsArrayMessage(
            self,
        ) -> global___ConsumerApplication.ContactsArrayMessage: ...
        @property
        def liveLocationMessage(
            self,
        ) -> global___ConsumerApplication.LiveLocationMessage: ...
        @property
        def stickerMessage(self) -> global___ConsumerApplication.StickerMessage: ...
        @property
        def groupInviteMessage(
            self,
        ) -> global___ConsumerApplication.GroupInviteMessage: ...
        @property
        def viewOnceMessage(self) -> global___ConsumerApplication.ViewOnceMessage: ...
        @property
        def reactionMessage(self) -> global___ConsumerApplication.ReactionMessage: ...
        @property
        def pollCreationMessage(
            self,
        ) -> global___ConsumerApplication.PollCreationMessage: ...
        @property
        def pollUpdateMessage(
            self,
        ) -> global___ConsumerApplication.PollUpdateMessage: ...
        @property
        def editMessage(self) -> global___ConsumerApplication.EditMessage: ...
        def __init__(
            self,
            *,
            messageText: waCommon.WACommon_pb2.MessageText | None = ...,
            imageMessage: global___ConsumerApplication.ImageMessage | None = ...,
            contactMessage: global___ConsumerApplication.ContactMessage | None = ...,
            locationMessage: global___ConsumerApplication.LocationMessage | None = ...,
            extendedTextMessage: global___ConsumerApplication.ExtendedTextMessage
            | None = ...,
            statusTextMessage: global___ConsumerApplication.StatusTextMesage
            | None = ...,
            documentMessage: global___ConsumerApplication.DocumentMessage | None = ...,
            audioMessage: global___ConsumerApplication.AudioMessage | None = ...,
            videoMessage: global___ConsumerApplication.VideoMessage | None = ...,
            contactsArrayMessage: global___ConsumerApplication.ContactsArrayMessage
            | None = ...,
            liveLocationMessage: global___ConsumerApplication.LiveLocationMessage
            | None = ...,
            stickerMessage: global___ConsumerApplication.StickerMessage | None = ...,
            groupInviteMessage: global___ConsumerApplication.GroupInviteMessage
            | None = ...,
            viewOnceMessage: global___ConsumerApplication.ViewOnceMessage | None = ...,
            reactionMessage: global___ConsumerApplication.ReactionMessage | None = ...,
            pollCreationMessage: global___ConsumerApplication.PollCreationMessage
            | None = ...,
            pollUpdateMessage: global___ConsumerApplication.PollUpdateMessage
            | None = ...,
            editMessage: global___ConsumerApplication.EditMessage | None = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing.Literal[
                "audioMessage",
                b"audioMessage",
                "contactMessage",
                b"contactMessage",
                "contactsArrayMessage",
                b"contactsArrayMessage",
                "content",
                b"content",
                "documentMessage",
                b"documentMessage",
                "editMessage",
                b"editMessage",
                "extendedTextMessage",
                b"extendedTextMessage",
                "groupInviteMessage",
                b"groupInviteMessage",
                "imageMessage",
                b"imageMessage",
                "liveLocationMessage",
                b"liveLocationMessage",
                "locationMessage",
                b"locationMessage",
                "messageText",
                b"messageText",
                "pollCreationMessage",
                b"pollCreationMessage",
                "pollUpdateMessage",
                b"pollUpdateMessage",
                "reactionMessage",
                b"reactionMessage",
                "statusTextMessage",
                b"statusTextMessage",
                "stickerMessage",
                b"stickerMessage",
                "videoMessage",
                b"videoMessage",
                "viewOnceMessage",
                b"viewOnceMessage",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing.Literal[
                "audioMessage",
                b"audioMessage",
                "contactMessage",
                b"contactMessage",
                "contactsArrayMessage",
                b"contactsArrayMessage",
                "content",
                b"content",
                "documentMessage",
                b"documentMessage",
                "editMessage",
                b"editMessage",
                "extendedTextMessage",
                b"extendedTextMessage",
                "groupInviteMessage",
                b"groupInviteMessage",
                "imageMessage",
                b"imageMessage",
                "liveLocationMessage",
                b"liveLocationMessage",
                "locationMessage",
                b"locationMessage",
                "messageText",
                b"messageText",
                "pollCreationMessage",
                b"pollCreationMessage",
                "pollUpdateMessage",
                b"pollUpdateMessage",
                "reactionMessage",
                b"reactionMessage",
                "statusTextMessage",
                b"statusTextMessage",
                "stickerMessage",
                b"stickerMessage",
                "videoMessage",
                b"videoMessage",
                "viewOnceMessage",
                b"viewOnceMessage",
            ],
        ) -> None: ...
        def WhichOneof(
            self, oneof_group: typing.Literal["content", b"content"]
        ) -> (
            typing.Literal[
                "messageText",
                "imageMessage",
                "contactMessage",
                "locationMessage",
                "extendedTextMessage",
                "statusTextMessage",
                "documentMessage",
                "audioMessage",
                "videoMessage",
                "contactsArrayMessage",
                "liveLocationMessage",
                "stickerMessage",
                "groupInviteMessage",
                "viewOnceMessage",
                "reactionMessage",
                "pollCreationMessage",
                "pollUpdateMessage",
                "editMessage",
            ]
            | None
        ): ...

    @typing.final
    class EditMessage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        MESSAGE_FIELD_NUMBER: builtins.int
        TIMESTAMPMS_FIELD_NUMBER: builtins.int
        timestampMS: builtins.int
        @property
        def key(self) -> waCommon.WACommon_pb2.MessageKey: ...
        @property
        def message(self) -> waCommon.WACommon_pb2.MessageText: ...
        def __init__(
            self,
            *,
            key: waCommon.WACommon_pb2.MessageKey | None = ...,
            message: waCommon.WACommon_pb2.MessageText | None = ...,
            timestampMS: builtins.int | None = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing.Literal[
                "key", b"key", "message", b"message", "timestampMS", b"timestampMS"
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing.Literal[
                "key", b"key", "message", b"message", "timestampMS", b"timestampMS"
            ],
        ) -> None: ...

    @typing.final
    class PollAddOptionMessage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        POLLOPTION_FIELD_NUMBER: builtins.int
        @property
        def pollOption(
            self,
        ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
            global___ConsumerApplication.Option
        ]: ...
        def __init__(
            self,
            *,
            pollOption: collections.abc.Iterable[global___ConsumerApplication.Option]
            | None = ...,
        ) -> None: ...
        def ClearField(
            self, field_name: typing.Literal["pollOption", b"pollOption"]
        ) -> None: ...

    @typing.final
    class PollVoteMessage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        SELECTEDOPTIONS_FIELD_NUMBER: builtins.int
        SENDERTIMESTAMPMS_FIELD_NUMBER: builtins.int
        senderTimestampMS: builtins.int
        @property
        def selectedOptions(
            self,
        ) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[
            builtins.bytes
        ]: ...
        def __init__(
            self,
            *,
            selectedOptions: collections.abc.Iterable[builtins.bytes] | None = ...,
            senderTimestampMS: builtins.int | None = ...,
        ) -> None: ...
        def HasField(
            self, field_name: typing.Literal["senderTimestampMS", b"senderTimestampMS"]
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing.Literal[
                "selectedOptions",
                b"selectedOptions",
                "senderTimestampMS",
                b"senderTimestampMS",
            ],
        ) -> None: ...

    @typing.final
    class PollEncValue(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ENCPAYLOAD_FIELD_NUMBER: builtins.int
        ENCIV_FIELD_NUMBER: builtins.int
        encPayload: builtins.bytes
        encIV: builtins.bytes
        def __init__(
            self,
            *,
            encPayload: builtins.bytes | None = ...,
            encIV: builtins.bytes | None = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing.Literal["encIV", b"encIV", "encPayload", b"encPayload"],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing.Literal["encIV", b"encIV", "encPayload", b"encPayload"],
        ) -> None: ...

    @typing.final
    class PollUpdateMessage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        POLLCREATIONMESSAGEKEY_FIELD_NUMBER: builtins.int
        VOTE_FIELD_NUMBER: builtins.int
        ADDOPTION_FIELD_NUMBER: builtins.int
        @property
        def pollCreationMessageKey(self) -> waCommon.WACommon_pb2.MessageKey: ...
        @property
        def vote(self) -> global___ConsumerApplication.PollEncValue: ...
        @property
        def addOption(self) -> global___ConsumerApplication.PollEncValue: ...
        def __init__(
            self,
            *,
            pollCreationMessageKey: waCommon.WACommon_pb2.MessageKey | None = ...,
            vote: global___ConsumerApplication.PollEncValue | None = ...,
            addOption: global___ConsumerApplication.PollEncValue | None = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing.Literal[
                "addOption",
                b"addOption",
                "pollCreationMessageKey",
                b"pollCreationMessageKey",
                "vote",
                b"vote",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing.Literal[
                "addOption",
                b"addOption",
                "pollCreationMessageKey",
                b"pollCreationMessageKey",
                "vote",
                b"vote",
            ],
        ) -> None: ...

    @typing.final
    class PollCreationMessage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ENCKEY_FIELD_NUMBER: builtins.int
        NAME_FIELD_NUMBER: builtins.int
        OPTIONS_FIELD_NUMBER: builtins.int
        SELECTABLEOPTIONSCOUNT_FIELD_NUMBER: builtins.int
        encKey: builtins.bytes
        name: builtins.str
        selectableOptionsCount: builtins.int
        @property
        def options(
            self,
        ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
            global___ConsumerApplication.Option
        ]: ...
        def __init__(
            self,
            *,
            encKey: builtins.bytes | None = ...,
            name: builtins.str | None = ...,
            options: collections.abc.Iterable[global___ConsumerApplication.Option]
            | None = ...,
            selectableOptionsCount: builtins.int | None = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing.Literal[
                "encKey",
                b"encKey",
                "name",
                b"name",
                "selectableOptionsCount",
                b"selectableOptionsCount",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing.Literal[
                "encKey",
                b"encKey",
                "name",
                b"name",
                "options",
                b"options",
                "selectableOptionsCount",
                b"selectableOptionsCount",
            ],
        ) -> None: ...

    @typing.final
    class Option(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        OPTIONNAME_FIELD_NUMBER: builtins.int
        optionName: builtins.str
        def __init__(
            self,
            *,
            optionName: builtins.str | None = ...,
        ) -> None: ...
        def HasField(
            self, field_name: typing.Literal["optionName", b"optionName"]
        ) -> builtins.bool: ...
        def ClearField(
            self, field_name: typing.Literal["optionName", b"optionName"]
        ) -> None: ...

    @typing.final
    class ReactionMessage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        TEXT_FIELD_NUMBER: builtins.int
        GROUPINGKEY_FIELD_NUMBER: builtins.int
        SENDERTIMESTAMPMS_FIELD_NUMBER: builtins.int
        REACTIONMETADATADATACLASSDATA_FIELD_NUMBER: builtins.int
        STYLE_FIELD_NUMBER: builtins.int
        text: builtins.str
        groupingKey: builtins.str
        senderTimestampMS: builtins.int
        reactionMetadataDataclassData: builtins.str
        style: builtins.int
        @property
        def key(self) -> waCommon.WACommon_pb2.MessageKey: ...
        def __init__(
            self,
            *,
            key: waCommon.WACommon_pb2.MessageKey | None = ...,
            text: builtins.str | None = ...,
            groupingKey: builtins.str | None = ...,
            senderTimestampMS: builtins.int | None = ...,
            reactionMetadataDataclassData: builtins.str | None = ...,
            style: builtins.int | None = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing.Literal[
                "groupingKey",
                b"groupingKey",
                "key",
                b"key",
                "reactionMetadataDataclassData",
                b"reactionMetadataDataclassData",
                "senderTimestampMS",
                b"senderTimestampMS",
                "style",
                b"style",
                "text",
                b"text",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing.Literal[
                "groupingKey",
                b"groupingKey",
                "key",
                b"key",
                "reactionMetadataDataclassData",
                b"reactionMetadataDataclassData",
                "senderTimestampMS",
                b"senderTimestampMS",
                "style",
                b"style",
                "text",
                b"text",
            ],
        ) -> None: ...

    @typing.final
    class RevokeMessage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        @property
        def key(self) -> waCommon.WACommon_pb2.MessageKey: ...
        def __init__(
            self,
            *,
            key: waCommon.WACommon_pb2.MessageKey | None = ...,
        ) -> None: ...
        def HasField(
            self, field_name: typing.Literal["key", b"key"]
        ) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["key", b"key"]) -> None: ...

    @typing.final
    class ViewOnceMessage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        IMAGEMESSAGE_FIELD_NUMBER: builtins.int
        VIDEOMESSAGE_FIELD_NUMBER: builtins.int
        @property
        def imageMessage(self) -> global___ConsumerApplication.ImageMessage: ...
        @property
        def videoMessage(self) -> global___ConsumerApplication.VideoMessage: ...
        def __init__(
            self,
            *,
            imageMessage: global___ConsumerApplication.ImageMessage | None = ...,
            videoMessage: global___ConsumerApplication.VideoMessage | None = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing.Literal[
                "imageMessage",
                b"imageMessage",
                "videoMessage",
                b"videoMessage",
                "viewOnceContent",
                b"viewOnceContent",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing.Literal[
                "imageMessage",
                b"imageMessage",
                "videoMessage",
                b"videoMessage",
                "viewOnceContent",
                b"viewOnceContent",
            ],
        ) -> None: ...
        def WhichOneof(
            self, oneof_group: typing.Literal["viewOnceContent", b"viewOnceContent"]
        ) -> typing.Literal["imageMessage", "videoMessage"] | None: ...

    @typing.final
    class GroupInviteMessage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        GROUPJID_FIELD_NUMBER: builtins.int
        INVITECODE_FIELD_NUMBER: builtins.int
        INVITEEXPIRATION_FIELD_NUMBER: builtins.int
        GROUPNAME_FIELD_NUMBER: builtins.int
        JPEGTHUMBNAIL_FIELD_NUMBER: builtins.int
        CAPTION_FIELD_NUMBER: builtins.int
        groupJID: builtins.str
        inviteCode: builtins.str
        inviteExpiration: builtins.int
        groupName: builtins.str
        JPEGThumbnail: builtins.bytes
        @property
        def caption(self) -> waCommon.WACommon_pb2.MessageText: ...
        def __init__(
            self,
            *,
            groupJID: builtins.str | None = ...,
            inviteCode: builtins.str | None = ...,
            inviteExpiration: builtins.int | None = ...,
            groupName: builtins.str | None = ...,
            JPEGThumbnail: builtins.bytes | None = ...,
            caption: waCommon.WACommon_pb2.MessageText | None = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing.Literal[
                "JPEGThumbnail",
                b"JPEGThumbnail",
                "caption",
                b"caption",
                "groupJID",
                b"groupJID",
                "groupName",
                b"groupName",
                "inviteCode",
                b"inviteCode",
                "inviteExpiration",
                b"inviteExpiration",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing.Literal[
                "JPEGThumbnail",
                b"JPEGThumbnail",
                "caption",
                b"caption",
                "groupJID",
                b"groupJID",
                "groupName",
                b"groupName",
                "inviteCode",
                b"inviteCode",
                "inviteExpiration",
                b"inviteExpiration",
            ],
        ) -> None: ...

    @typing.final
    class LiveLocationMessage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        LOCATION_FIELD_NUMBER: builtins.int
        ACCURACYINMETERS_FIELD_NUMBER: builtins.int
        SPEEDINMPS_FIELD_NUMBER: builtins.int
        DEGREESCLOCKWISEFROMMAGNETICNORTH_FIELD_NUMBER: builtins.int
        CAPTION_FIELD_NUMBER: builtins.int
        SEQUENCENUMBER_FIELD_NUMBER: builtins.int
        TIMEOFFSET_FIELD_NUMBER: builtins.int
        accuracyInMeters: builtins.int
        speedInMps: builtins.float
        degreesClockwiseFromMagneticNorth: builtins.int
        sequenceNumber: builtins.int
        timeOffset: builtins.int
        @property
        def location(self) -> global___ConsumerApplication.Location: ...
        @property
        def caption(self) -> waCommon.WACommon_pb2.MessageText: ...
        def __init__(
            self,
            *,
            location: global___ConsumerApplication.Location | None = ...,
            accuracyInMeters: builtins.int | None = ...,
            speedInMps: builtins.float | None = ...,
            degreesClockwiseFromMagneticNorth: builtins.int | None = ...,
            caption: waCommon.WACommon_pb2.MessageText | None = ...,
            sequenceNumber: builtins.int | None = ...,
            timeOffset: builtins.int | None = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing.Literal[
                "accuracyInMeters",
                b"accuracyInMeters",
                "caption",
                b"caption",
                "degreesClockwiseFromMagneticNorth",
                b"degreesClockwiseFromMagneticNorth",
                "location",
                b"location",
                "sequenceNumber",
                b"sequenceNumber",
                "speedInMps",
                b"speedInMps",
                "timeOffset",
                b"timeOffset",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing.Literal[
                "accuracyInMeters",
                b"accuracyInMeters",
                "caption",
                b"caption",
                "degreesClockwiseFromMagneticNorth",
                b"degreesClockwiseFromMagneticNorth",
                "location",
                b"location",
                "sequenceNumber",
                b"sequenceNumber",
                "speedInMps",
                b"speedInMps",
                "timeOffset",
                b"timeOffset",
            ],
        ) -> None: ...

    @typing.final
    class ContactsArrayMessage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        DISPLAYNAME_FIELD_NUMBER: builtins.int
        CONTACTS_FIELD_NUMBER: builtins.int
        displayName: builtins.str
        @property
        def contacts(
            self,
        ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
            global___ConsumerApplication.ContactMessage
        ]: ...
        def __init__(
            self,
            *,
            displayName: builtins.str | None = ...,
            contacts: collections.abc.Iterable[
                global___ConsumerApplication.ContactMessage
            ]
            | None = ...,
        ) -> None: ...
        def HasField(
            self, field_name: typing.Literal["displayName", b"displayName"]
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing.Literal[
                "contacts", b"contacts", "displayName", b"displayName"
            ],
        ) -> None: ...

    @typing.final
    class ContactMessage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CONTACT_FIELD_NUMBER: builtins.int
        @property
        def contact(self) -> waCommon.WACommon_pb2.SubProtocol: ...
        def __init__(
            self,
            *,
            contact: waCommon.WACommon_pb2.SubProtocol | None = ...,
        ) -> None: ...
        def HasField(
            self, field_name: typing.Literal["contact", b"contact"]
        ) -> builtins.bool: ...
        def ClearField(
            self, field_name: typing.Literal["contact", b"contact"]
        ) -> None: ...

    @typing.final
    class StatusTextMesage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _FontType:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _FontTypeEnumTypeWrapper(
            google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
                ConsumerApplication.StatusTextMesage._FontType.ValueType
            ],
            builtins.type,
        ):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            SANS_SERIF: ConsumerApplication.StatusTextMesage._FontType.ValueType  # 0
            SERIF: ConsumerApplication.StatusTextMesage._FontType.ValueType  # 1
            NORICAN_REGULAR: (
                ConsumerApplication.StatusTextMesage._FontType.ValueType
            )  # 2
            BRYNDAN_WRITE: ConsumerApplication.StatusTextMesage._FontType.ValueType  # 3
            BEBASNEUE_REGULAR: (
                ConsumerApplication.StatusTextMesage._FontType.ValueType
            )  # 4
            OSWALD_HEAVY: ConsumerApplication.StatusTextMesage._FontType.ValueType  # 5

        class FontType(_FontType, metaclass=_FontTypeEnumTypeWrapper): ...
        SANS_SERIF: ConsumerApplication.StatusTextMesage.FontType.ValueType  # 0
        SERIF: ConsumerApplication.StatusTextMesage.FontType.ValueType  # 1
        NORICAN_REGULAR: ConsumerApplication.StatusTextMesage.FontType.ValueType  # 2
        BRYNDAN_WRITE: ConsumerApplication.StatusTextMesage.FontType.ValueType  # 3
        BEBASNEUE_REGULAR: ConsumerApplication.StatusTextMesage.FontType.ValueType  # 4
        OSWALD_HEAVY: ConsumerApplication.StatusTextMesage.FontType.ValueType  # 5

        TEXT_FIELD_NUMBER: builtins.int
        TEXTARGB_FIELD_NUMBER: builtins.int
        BACKGROUNDARGB_FIELD_NUMBER: builtins.int
        FONT_FIELD_NUMBER: builtins.int
        textArgb: builtins.int
        backgroundArgb: builtins.int
        font: global___ConsumerApplication.StatusTextMesage.FontType.ValueType
        @property
        def text(self) -> global___ConsumerApplication.ExtendedTextMessage: ...
        def __init__(
            self,
            *,
            text: global___ConsumerApplication.ExtendedTextMessage | None = ...,
            textArgb: builtins.int | None = ...,
            backgroundArgb: builtins.int | None = ...,
            font: global___ConsumerApplication.StatusTextMesage.FontType.ValueType
            | None = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing.Literal[
                "backgroundArgb",
                b"backgroundArgb",
                "font",
                b"font",
                "text",
                b"text",
                "textArgb",
                b"textArgb",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing.Literal[
                "backgroundArgb",
                b"backgroundArgb",
                "font",
                b"font",
                "text",
                b"text",
                "textArgb",
                b"textArgb",
            ],
        ) -> None: ...

    @typing.final
    class ExtendedTextMessage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _PreviewType:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _PreviewTypeEnumTypeWrapper(
            google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
                ConsumerApplication.ExtendedTextMessage._PreviewType.ValueType
            ],
            builtins.type,
        ):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            NONE: ConsumerApplication.ExtendedTextMessage._PreviewType.ValueType  # 0
            VIDEO: ConsumerApplication.ExtendedTextMessage._PreviewType.ValueType  # 1

        class PreviewType(_PreviewType, metaclass=_PreviewTypeEnumTypeWrapper): ...
        NONE: ConsumerApplication.ExtendedTextMessage.PreviewType.ValueType  # 0
        VIDEO: ConsumerApplication.ExtendedTextMessage.PreviewType.ValueType  # 1

        TEXT_FIELD_NUMBER: builtins.int
        MATCHEDTEXT_FIELD_NUMBER: builtins.int
        CANONICALURL_FIELD_NUMBER: builtins.int
        DESCRIPTION_FIELD_NUMBER: builtins.int
        TITLE_FIELD_NUMBER: builtins.int
        THUMBNAIL_FIELD_NUMBER: builtins.int
        PREVIEWTYPE_FIELD_NUMBER: builtins.int
        matchedText: builtins.str
        canonicalURL: builtins.str
        description: builtins.str
        title: builtins.str
        previewType: (
            global___ConsumerApplication.ExtendedTextMessage.PreviewType.ValueType
        )
        @property
        def text(self) -> waCommon.WACommon_pb2.MessageText: ...
        @property
        def thumbnail(self) -> waCommon.WACommon_pb2.SubProtocol: ...
        def __init__(
            self,
            *,
            text: waCommon.WACommon_pb2.MessageText | None = ...,
            matchedText: builtins.str | None = ...,
            canonicalURL: builtins.str | None = ...,
            description: builtins.str | None = ...,
            title: builtins.str | None = ...,
            thumbnail: waCommon.WACommon_pb2.SubProtocol | None = ...,
            previewType: global___ConsumerApplication.ExtendedTextMessage.PreviewType.ValueType
            | None = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing.Literal[
                "canonicalURL",
                b"canonicalURL",
                "description",
                b"description",
                "matchedText",
                b"matchedText",
                "previewType",
                b"previewType",
                "text",
                b"text",
                "thumbnail",
                b"thumbnail",
                "title",
                b"title",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing.Literal[
                "canonicalURL",
                b"canonicalURL",
                "description",
                b"description",
                "matchedText",
                b"matchedText",
                "previewType",
                b"previewType",
                "text",
                b"text",
                "thumbnail",
                b"thumbnail",
                "title",
                b"title",
            ],
        ) -> None: ...

    @typing.final
    class LocationMessage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        LOCATION_FIELD_NUMBER: builtins.int
        ADDRESS_FIELD_NUMBER: builtins.int
        address: builtins.str
        @property
        def location(self) -> global___ConsumerApplication.Location: ...
        def __init__(
            self,
            *,
            location: global___ConsumerApplication.Location | None = ...,
            address: builtins.str | None = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing.Literal["address", b"address", "location", b"location"],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing.Literal["address", b"address", "location", b"location"],
        ) -> None: ...

    @typing.final
    class StickerMessage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        STICKER_FIELD_NUMBER: builtins.int
        @property
        def sticker(self) -> waCommon.WACommon_pb2.SubProtocol: ...
        def __init__(
            self,
            *,
            sticker: waCommon.WACommon_pb2.SubProtocol | None = ...,
        ) -> None: ...
        def HasField(
            self, field_name: typing.Literal["sticker", b"sticker"]
        ) -> builtins.bool: ...
        def ClearField(
            self, field_name: typing.Literal["sticker", b"sticker"]
        ) -> None: ...

    @typing.final
    class DocumentMessage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        DOCUMENT_FIELD_NUMBER: builtins.int
        FILENAME_FIELD_NUMBER: builtins.int
        fileName: builtins.str
        @property
        def document(self) -> waCommon.WACommon_pb2.SubProtocol: ...
        def __init__(
            self,
            *,
            document: waCommon.WACommon_pb2.SubProtocol | None = ...,
            fileName: builtins.str | None = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing.Literal[
                "document", b"document", "fileName", b"fileName"
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing.Literal[
                "document", b"document", "fileName", b"fileName"
            ],
        ) -> None: ...

    @typing.final
    class VideoMessage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        VIDEO_FIELD_NUMBER: builtins.int
        CAPTION_FIELD_NUMBER: builtins.int
        @property
        def video(self) -> waCommon.WACommon_pb2.SubProtocol: ...
        @property
        def caption(self) -> waCommon.WACommon_pb2.MessageText: ...
        def __init__(
            self,
            *,
            video: waCommon.WACommon_pb2.SubProtocol | None = ...,
            caption: waCommon.WACommon_pb2.MessageText | None = ...,
        ) -> None: ...
        def HasField(
            self, field_name: typing.Literal["caption", b"caption", "video", b"video"]
        ) -> builtins.bool: ...
        def ClearField(
            self, field_name: typing.Literal["caption", b"caption", "video", b"video"]
        ) -> None: ...

    @typing.final
    class AudioMessage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        AUDIO_FIELD_NUMBER: builtins.int
        PTT_FIELD_NUMBER: builtins.int
        PTT: builtins.bool
        @property
        def audio(self) -> waCommon.WACommon_pb2.SubProtocol: ...
        def __init__(
            self,
            *,
            audio: waCommon.WACommon_pb2.SubProtocol | None = ...,
            PTT: builtins.bool | None = ...,
        ) -> None: ...
        def HasField(
            self, field_name: typing.Literal["PTT", b"PTT", "audio", b"audio"]
        ) -> builtins.bool: ...
        def ClearField(
            self, field_name: typing.Literal["PTT", b"PTT", "audio", b"audio"]
        ) -> None: ...

    @typing.final
    class ImageMessage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        IMAGE_FIELD_NUMBER: builtins.int
        CAPTION_FIELD_NUMBER: builtins.int
        @property
        def image(self) -> waCommon.WACommon_pb2.SubProtocol: ...
        @property
        def caption(self) -> waCommon.WACommon_pb2.MessageText: ...
        def __init__(
            self,
            *,
            image: waCommon.WACommon_pb2.SubProtocol | None = ...,
            caption: waCommon.WACommon_pb2.MessageText | None = ...,
        ) -> None: ...
        def HasField(
            self, field_name: typing.Literal["caption", b"caption", "image", b"image"]
        ) -> builtins.bool: ...
        def ClearField(
            self, field_name: typing.Literal["caption", b"caption", "image", b"image"]
        ) -> None: ...

    @typing.final
    class InteractiveAnnotation(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        LOCATION_FIELD_NUMBER: builtins.int
        POLYGONVERTICES_FIELD_NUMBER: builtins.int
        @property
        def location(self) -> global___ConsumerApplication.Location: ...
        @property
        def polygonVertices(
            self,
        ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
            global___ConsumerApplication.Point
        ]: ...
        def __init__(
            self,
            *,
            location: global___ConsumerApplication.Location | None = ...,
            polygonVertices: collections.abc.Iterable[
                global___ConsumerApplication.Point
            ]
            | None = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing.Literal["action", b"action", "location", b"location"],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing.Literal[
                "action",
                b"action",
                "location",
                b"location",
                "polygonVertices",
                b"polygonVertices",
            ],
        ) -> None: ...
        def WhichOneof(
            self, oneof_group: typing.Literal["action", b"action"]
        ) -> typing.Literal["location"] | None: ...

    @typing.final
    class Point(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        X_FIELD_NUMBER: builtins.int
        Y_FIELD_NUMBER: builtins.int
        x: builtins.float
        y: builtins.float
        def __init__(
            self,
            *,
            x: builtins.float | None = ...,
            y: builtins.float | None = ...,
        ) -> None: ...
        def HasField(
            self, field_name: typing.Literal["x", b"x", "y", b"y"]
        ) -> builtins.bool: ...
        def ClearField(
            self, field_name: typing.Literal["x", b"x", "y", b"y"]
        ) -> None: ...

    @typing.final
    class Location(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        DEGREESLATITUDE_FIELD_NUMBER: builtins.int
        DEGREESLONGITUDE_FIELD_NUMBER: builtins.int
        NAME_FIELD_NUMBER: builtins.int
        degreesLatitude: builtins.float
        degreesLongitude: builtins.float
        name: builtins.str
        def __init__(
            self,
            *,
            degreesLatitude: builtins.float | None = ...,
            degreesLongitude: builtins.float | None = ...,
            name: builtins.str | None = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing.Literal[
                "degreesLatitude",
                b"degreesLatitude",
                "degreesLongitude",
                b"degreesLongitude",
                "name",
                b"name",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing.Literal[
                "degreesLatitude",
                b"degreesLatitude",
                "degreesLongitude",
                b"degreesLongitude",
                "name",
                b"name",
            ],
        ) -> None: ...

    @typing.final
    class MediaPayload(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        PROTOCOL_FIELD_NUMBER: builtins.int
        @property
        def protocol(self) -> waCommon.WACommon_pb2.SubProtocol: ...
        def __init__(
            self,
            *,
            protocol: waCommon.WACommon_pb2.SubProtocol | None = ...,
        ) -> None: ...
        def HasField(
            self, field_name: typing.Literal["protocol", b"protocol"]
        ) -> builtins.bool: ...
        def ClearField(
            self, field_name: typing.Literal["protocol", b"protocol"]
        ) -> None: ...

    PAYLOAD_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    @property
    def payload(self) -> global___ConsumerApplication.Payload: ...
    @property
    def metadata(self) -> global___ConsumerApplication.Metadata: ...
    def __init__(
        self,
        *,
        payload: global___ConsumerApplication.Payload | None = ...,
        metadata: global___ConsumerApplication.Metadata | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["metadata", b"metadata", "payload", b"payload"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing.Literal["metadata", b"metadata", "payload", b"payload"]
    ) -> None: ...

global___ConsumerApplication = ConsumerApplication



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: waUserPassword/WAProtobufsUserPassword.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n,waUserPassword/WAProtobufsUserPassword.proto\x12\x17WAProtobufsUserPassword"\x9b\x04\n\x0cUserPassword\x12@\n\x08\x65ncoding\x18\x01 \x01(\x0e\x32..WAProtobufsUserPassword.UserPassword.Encoding\x12\x46\n\x0btransformer\x18\x02 \x01(\x0e\x32\x31.WAProtobufsUserPassword.UserPassword.Transformer\x12L\n\x0etransformerArg\x18\x03 \x03(\x0b\x32\x34.WAProtobufsUserPassword.UserPassword.TransformerArg\x12\x17\n\x0ftransformedData\x18\x04 \x01(\x0c\x1a\xa9\x01\n\x0eTransformerArg\x12\x0b\n\x03key\x18\x01 \x01(\t\x12I\n\x05value\x18\x02 \x01(\x0b\x32:.WAProtobufsUserPassword.UserPassword.TransformerArg.Value\x1a?\n\x05Value\x12\x10\n\x06\x61sBlob\x18\x01 \x01(\x0cH\x00\x12\x1b\n\x11\x61sUnsignedInteger\x18\x02 \x01(\rH\x00\x42\x07\n\x05value"G\n\x0bTransformer\x12\x08\n\x04NONE\x10\x00\x12\x16\n\x12PBKDF2_HMAC_SHA512\x10\x01\x12\x16\n\x12PBKDF2_HMAC_SHA384\x10\x02"%\n\x08\x45ncoding\x12\x08\n\x04UTF8\x10\x00\x12\x0f\n\x0bUTF8_BROKEN\x10\x01\x42*Z(go.mau.fi/whatsmeow/proto/waUserPassword'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "waUserPassword.WAProtobufsUserPassword_pb2", _globals
)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"Z(go.mau.fi/whatsmeow/proto/waUserPassword"
    _globals["_USERPASSWORD"]._serialized_start = 74
    _globals["_USERPASSWORD"]._serialized_end = 613
    _globals["_USERPASSWORD_TRANSFORMERARG"]._serialized_start = 332
    _globals["_USERPASSWORD_TRANSFORMERARG"]._serialized_end = 501
    _globals["_USERPASSWORD_TRANSFORMERARG_VALUE"]._serialized_start = 438
    _globals["_USERPASSWORD_TRANSFORMERARG_VALUE"]._serialized_end = 501
    _globals["_USERPASSWORD_TRANSFORMER"]._serialized_start = 503
    _globals["_USERPASSWORD_TRANSFORMER"]._serialized_end = 574
    _globals["_USERPASSWORD_ENCODING"]._serialized_start = 576
    _globals["_USERPASSWORD_ENCODING"]._serialized_end = 613
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class DeviceCapabilities(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ChatLockSupportLevel:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ChatLockSupportLevelEnumTypeWrapper(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            DeviceCapabilities._ChatLockSupportLevel.ValueType
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        NONE: DeviceCapabilities._ChatLockSupportLevel.ValueType  # 0
        MINIMAL: DeviceCapabilities._ChatLockSupportLevel.ValueType  # 1
        FULL: DeviceCapabilities._ChatLockSupportLevel.ValueType  # 2

    class ChatLockSupportLevel(
        _ChatLockSupportLevel, metaclass=_ChatLockSupportLevelEnumTypeWrapper
    ): ...
    NONE: DeviceCapabilities.ChatLockSupportLevel.ValueType  # 0
    MINIMAL: DeviceCapabilities.ChatLockSupportLevel.ValueType  # 1
    FULL: DeviceCapabilities.ChatLockSupportLevel.ValueType  # 2

    CHATLOCKSUPPORTLEVEL_FIELD_NUMBER: builtins.int
    chatLockSupportLevel: global___DeviceCapabilities.ChatLockSupportLevel.ValueType
    def __init__(
        self,
        *,
        chatLockSupportLevel: global___DeviceCapabilities.ChatLockSupportLevel.ValueType
        | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal["chatLockSupportLevel", b"chatLockSupportLevel"],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal["chatLockSupportLevel", b"chatLockSupportLevel"],
    ) -> None: ...

global___DeviceCapabilities = DeviceCapabilities



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _HostedState:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _HostedStateEnumTypeWrapper(
    google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_HostedState.ValueType],
    builtins.type,
):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    E2EE: _HostedState.ValueType  # 0
    HOSTED: _HostedState.ValueType  # 1

class HostedState(_HostedState, metaclass=_HostedStateEnumTypeWrapper): ...

E2EE: HostedState.ValueType  # 0
HOSTED: HostedState.ValueType  # 1
global___HostedState = HostedState

@typing.final
class FingerprintData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PUBLICKEY_FIELD_NUMBER: builtins.int
    PNIDENTIFIER_FIELD_NUMBER: builtins.int
    LIDIDENTIFIER_FIELD_NUMBER: builtins.int
    USERNAMEIDENTIFIER_FIELD_NUMBER: builtins.int
    HOSTEDSTATE_FIELD_NUMBER: builtins.int
    publicKey: builtins.bytes
    pnIdentifier: builtins.bytes
    lidIdentifier: builtins.bytes
    usernameIdentifier: builtins.bytes
    hostedState: global___HostedState.ValueType
    def __init__(
        self,
        *,
        publicKey: builtins.bytes | None = ...,
        pnIdentifier: builtins.bytes | None = ...,
        lidIdentifier: builtins.bytes | None = ...,
        usernameIdentifier: builtins.bytes | None = ...,
        hostedState: global___HostedState.ValueType | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "hostedState",
            b"hostedState",
            "lidIdentifier",
            b"lidIdentifier",
            "pnIdentifier",
            b"pnIdentifier",
            "publicKey",
            b"publicKey",
            "usernameIdentifier",
            b"usernameIdentifier",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "hostedState",
            b"hostedState",
            "lidIdentifier",
            b"lidIdentifier",
            "pnIdentifier",
            b"pnIdentifier",
            "publicKey",
            b"publicKey",
            "usernameIdentifier",
            b"usernameIdentifier",
        ],
    ) -> None: ...

global___FingerprintData = FingerprintData

@typing.final
class CombinedFingerprint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    LOCALFINGERPRINT_FIELD_NUMBER: builtins.int
    REMOTEFINGERPRINT_FIELD_NUMBER: builtins.int
    version: builtins.int
    @property
    def localFingerprint(self) -> global___FingerprintData: ...
    @property
    def remoteFingerprint(self) -> global___FingerprintData: ...
    def __init__(
        self,
        *,
        version: builtins.int | None = ...,
        localFingerprint: global___FingerprintData | None = ...,
        remoteFingerprint: global___FingerprintData | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "localFingerprint",
            b"localFingerprint",
            "remoteFingerprint",
            b"remoteFingerprint",
            "version",
            b"version",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "localFingerprint",
            b"localFingerprint",
            "remoteFingerprint",
            b"remoteFingerprint",
            "version",
            b"version",
        ],
    ) -> None: ...

global___CombinedFingerprint = CombinedFingerprint



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: waAdv/WAAdv.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x11waAdv/WAAdv.proto\x12\x05WAAdv"\x92\x01\n\x0f\x41\x44VKeyIndexList\x12\r\n\x05rawID\x18\x01 \x01(\r\x12\x11\n\ttimestamp\x18\x02 \x01(\x04\x12\x14\n\x0c\x63urrentIndex\x18\x03 \x01(\r\x12\x18\n\x0cvalidIndexes\x18\x04 \x03(\rB\x02\x10\x01\x12-\n\x0b\x61\x63\x63ountType\x18\x05 \x01(\x0e\x32\x18.WAAdv.ADVEncryptionType"_\n\x15\x41\x44VSignedKeyIndexList\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\x0c\x12\x18\n\x10\x61\x63\x63ountSignature\x18\x02 \x01(\x0c\x12\x1b\n\x13\x61\x63\x63ountSignatureKey\x18\x03 \x01(\x0c"\xa4\x01\n\x11\x41\x44VDeviceIdentity\x12\r\n\x05rawID\x18\x01 \x01(\r\x12\x11\n\ttimestamp\x18\x02 \x01(\x04\x12\x10\n\x08keyIndex\x18\x03 \x01(\r\x12-\n\x0b\x61\x63\x63ountType\x18\x04 \x01(\x0e\x32\x18.WAAdv.ADVEncryptionType\x12,\n\ndeviceType\x18\x05 \x01(\x0e\x32\x18.WAAdv.ADVEncryptionType"z\n\x17\x41\x44VSignedDeviceIdentity\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\x0c\x12\x1b\n\x13\x61\x63\x63ountSignatureKey\x18\x02 \x01(\x0c\x12\x18\n\x10\x61\x63\x63ountSignature\x18\x03 \x01(\x0c\x12\x17\n\x0f\x64\x65viceSignature\x18\x04 \x01(\x0c"k\n\x1b\x41\x44VSignedDeviceIdentityHMAC\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\x0c\x12\x0c\n\x04HMAC\x18\x02 \x01(\x0c\x12-\n\x0b\x61\x63\x63ountType\x18\x03 \x01(\x0e\x32\x18.WAAdv.ADVEncryptionType*)\n\x11\x41\x44VEncryptionType\x12\x08\n\x04\x45\x32\x45\x45\x10\x00\x12\n\n\x06HOSTED\x10\x01\x42!Z\x1fgo.mau.fi/whatsmeow/proto/waAdv'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "waAdv.WAAdv_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\037go.mau.fi/whatsmeow/proto/waAdv"
    _globals["_ADVKEYINDEXLIST"].fields_by_name["validIndexes"]._options = None
    _globals["_ADVKEYINDEXLIST"].fields_by_name[
        "validIndexes"
    ]._serialized_options = b"\020\001"
    _globals["_ADVENCRYPTIONTYPE"]._serialized_start = 674
    _globals["_ADVENCRYPTIONTYPE"]._serialized_end = 715
    _globals["_ADVKEYINDEXLIST"]._serialized_start = 29
    _globals["_ADVKEYINDEXLIST"]._serialized_end = 175
    _globals["_ADVSIGNEDKEYINDEXLIST"]._serialized_start = 177
    _globals["_ADVSIGNEDKEYINDEXLIST"]._serialized_end = 272
    _globals["_ADVDEVICEIDENTITY"]._serialized_start = 275
    _globals["_ADVDEVICEIDENTITY"]._serialized_end = 439
    _globals["_ADVSIGNEDDEVICEIDENTITY"]._serialized_start = 441
    _globals["_ADVSIGNEDDEVICEIDENTITY"]._serialized_end = 563
    _globals["_ADVSIGNEDDEVICEIDENTITYHMAC"]._serialized_start = 565
    _globals["_ADVSIGNEDDEVICEIDENTITYHMAC"]._serialized_end = 672
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: waDeviceCapabilities/WAProtobufsDeviceCapabilities.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n8waDeviceCapabilities/WAProtobufsDeviceCapabilities.proto\x12\x1dWAProtobufsDeviceCapabilities"\xb3\x01\n\x12\x44\x65viceCapabilities\x12\x64\n\x14\x63hatLockSupportLevel\x18\x01 \x01(\x0e\x32\x46.WAProtobufsDeviceCapabilities.DeviceCapabilities.ChatLockSupportLevel"7\n\x14\x43hatLockSupportLevel\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07MINIMAL\x10\x01\x12\x08\n\x04\x46ULL\x10\x02\x42\x30Z.go.mau.fi/whatsmeow/proto/waDeviceCapabilities'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "waDeviceCapabilities.WAProtobufsDeviceCapabilities_pb2", _globals
)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"Z.go.mau.fi/whatsmeow/proto/waDeviceCapabilities"
    _globals["_DEVICECAPABILITIES"]._serialized_start = 92
    _globals["_DEVICECAPABILITIES"]._serialized_end = 271
    _globals["_DEVICECAPABILITIES_CHATLOCKSUPPORTLEVEL"]._serialized_start = 216
    _globals["_DEVICECAPABILITIES_CHATLOCKSUPPORTLEVEL"]._serialized_end = 271
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: waConsumerApplication/WAConsumerApplication.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from waCommon import WACommon_pb2 as waCommon_dot_WACommon__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n1waConsumerApplication/WAConsumerApplication.proto\x12\x15WAConsumerApplication\x1a\x17waCommon/WACommon.proto"\xca,\n\x13\x43onsumerApplication\x12\x43\n\x07payload\x18\x01 \x01(\x0b\x32\x32.WAConsumerApplication.ConsumerApplication.Payload\x12\x45\n\x08metadata\x18\x02 \x01(\x0b\x32\x33.WAConsumerApplication.ConsumerApplication.Metadata\x1a\xcd\x02\n\x07Payload\x12\x45\n\x07\x63ontent\x18\x01 \x01(\x0b\x32\x32.WAConsumerApplication.ConsumerApplication.ContentH\x00\x12U\n\x0f\x61pplicationData\x18\x02 \x01(\x0b\x32:.WAConsumerApplication.ConsumerApplication.ApplicationDataH\x00\x12\x43\n\x06signal\x18\x03 \x01(\x0b\x32\x31.WAConsumerApplication.ConsumerApplication.SignalH\x00\x12T\n\x0bsubProtocol\x18\x04 \x01(\x0b\x32=.WAConsumerApplication.ConsumerApplication.SubProtocolPayloadH\x00\x42\t\n\x07payload\x1aH\n\x12SubProtocolPayload\x12\x32\n\x0b\x66utureProof\x18\x01 \x01(\x0e\x32\x1d.WACommon.FutureProofBehavior\x1a\x9d\x01\n\x08Metadata\x12\\\n\x0fspecialTextSize\x18\x01 \x01(\x0e\x32\x43.WAConsumerApplication.ConsumerApplication.Metadata.SpecialTextSize"3\n\x0fSpecialTextSize\x12\t\n\x05SMALL\x10\x01\x12\n\n\x06MEDIUM\x10\x02\x12\t\n\x05LARGE\x10\x03\x1a\x08\n\x06Signal\x1as\n\x0f\x41pplicationData\x12J\n\x06revoke\x18\x01 \x01(\x0b\x32\x38.WAConsumerApplication.ConsumerApplication.RevokeMessageH\x00\x42\x14\n\x12\x61pplicationContent\x1a\x9a\x0c\n\x07\x43ontent\x12,\n\x0bmessageText\x18\x01 \x01(\x0b\x32\x15.WACommon.MessageTextH\x00\x12O\n\x0cimageMessage\x18\x02 \x01(\x0b\x32\x37.WAConsumerApplication.ConsumerApplication.ImageMessageH\x00\x12S\n\x0e\x63ontactMessage\x18\x03 \x01(\x0b\x32\x39.WAConsumerApplication.ConsumerApplication.ContactMessageH\x00\x12U\n\x0flocationMessage\x18\x04 \x01(\x0b\x32:.WAConsumerApplication.ConsumerApplication.LocationMessageH\x00\x12]\n\x13\x65xtendedTextMessage\x18\x05 \x01(\x0b\x32>.WAConsumerApplication.ConsumerApplication.ExtendedTextMessageH\x00\x12X\n\x11statusTextMessage\x18\x06 \x01(\x0b\x32;.WAConsumerApplication.ConsumerApplication.StatusTextMesageH\x00\x12U\n\x0f\x64ocumentMessage\x18\x07 \x01(\x0b\x32:.WAConsumerApplication.ConsumerApplication.DocumentMessageH\x00\x12O\n\x0c\x61udioMessage\x18\x08 \x01(\x0b\x32\x37.WAConsumerApplication.ConsumerApplication.AudioMessageH\x00\x12O\n\x0cvideoMessage\x18\t \x01(\x0b\x32\x37.WAConsumerApplication.ConsumerApplication.VideoMessageH\x00\x12_\n\x14\x63ontactsArrayMessage\x18\n \x01(\x0b\x32?.WAConsumerApplication.ConsumerApplication.ContactsArrayMessageH\x00\x12]\n\x13liveLocationMessage\x18\x0b \x01(\x0b\x32>.WAConsumerApplication.ConsumerApplication.LiveLocationMessageH\x00\x12S\n\x0estickerMessage\x18\x0c \x01(\x0b\x32\x39.WAConsumerApplication.ConsumerApplication.StickerMessageH\x00\x12[\n\x12groupInviteMessage\x18\r \x01(\x0b\x32=.WAConsumerApplication.ConsumerApplication.GroupInviteMessageH\x00\x12U\n\x0fviewOnceMessage\x18\x0e \x01(\x0b\x32:.WAConsumerApplication.ConsumerApplication.ViewOnceMessageH\x00\x12U\n\x0freactionMessage\x18\x10 \x01(\x0b\x32:.WAConsumerApplication.ConsumerApplication.ReactionMessageH\x00\x12]\n\x13pollCreationMessage\x18\x11 \x01(\x0b\x32>.WAConsumerApplication.ConsumerApplication.PollCreationMessageH\x00\x12Y\n\x11pollUpdateMessage\x18\x12 \x01(\x0b\x32<.WAConsumerApplication.ConsumerApplication.PollUpdateMessageH\x00\x12M\n\x0b\x65\x64itMessage\x18\x13 \x01(\x0b\x32\x36.WAConsumerApplication.ConsumerApplication.EditMessageH\x00\x42\t\n\x07\x63ontent\x1am\n\x0b\x45\x64itMessage\x12!\n\x03key\x18\x01 \x01(\x0b\x32\x14.WACommon.MessageKey\x12&\n\x07message\x18\x02 \x01(\x0b\x32\x15.WACommon.MessageText\x12\x13\n\x0btimestampMS\x18\x03 \x01(\x03\x1a]\n\x14PollAddOptionMessage\x12\x45\n\npollOption\x18\x01 \x03(\x0b\x32\x31.WAConsumerApplication.ConsumerApplication.Option\x1a\x45\n\x0fPollVoteMessage\x12\x17\n\x0fselectedOptions\x18\x01 \x03(\x0c\x12\x19\n\x11senderTimestampMS\x18\x02 \x01(\x03\x1a\x31\n\x0cPollEncValue\x12\x12\n\nencPayload\x18\x01 \x01(\x0c\x12\r\n\x05\x65ncIV\x18\x02 \x01(\x0c\x1a\xdc\x01\n\x11PollUpdateMessage\x12\x34\n\x16pollCreationMessageKey\x18\x01 \x01(\x0b\x32\x14.WACommon.MessageKey\x12\x45\n\x04vote\x18\x02 \x01(\x0b\x32\x37.WAConsumerApplication.ConsumerApplication.PollEncValue\x12J\n\taddOption\x18\x03 \x01(\x0b\x32\x37.WAConsumerApplication.ConsumerApplication.PollEncValue\x1a\x97\x01\n\x13PollCreationMessage\x12\x0e\n\x06\x65ncKey\x18\x01 \x01(\x0c\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x42\n\x07options\x18\x03 \x03(\x0b\x32\x31.WAConsumerApplication.ConsumerApplication.Option\x12\x1e\n\x16selectableOptionsCount\x18\x04 \x01(\r\x1a\x1c\n\x06Option\x12\x12\n\noptionName\x18\x01 \x01(\t\x1a\xa8\x01\n\x0fReactionMessage\x12!\n\x03key\x18\x01 \x01(\x0b\x32\x14.WACommon.MessageKey\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x13\n\x0bgroupingKey\x18\x03 \x01(\t\x12\x19\n\x11senderTimestampMS\x18\x04 \x01(\x03\x12%\n\x1dreactionMetadataDataclassData\x18\x05 \x01(\t\x12\r\n\x05style\x18\x06 \x01(\x05\x1a\x32\n\rRevokeMessage\x12!\n\x03key\x18\x01 \x01(\x0b\x32\x14.WACommon.MessageKey\x1a\xc6\x01\n\x0fViewOnceMessage\x12O\n\x0cimageMessage\x18\x01 \x01(\x0b\x32\x37.WAConsumerApplication.ConsumerApplication.ImageMessageH\x00\x12O\n\x0cvideoMessage\x18\x02 \x01(\x0b\x32\x37.WAConsumerApplication.ConsumerApplication.VideoMessageH\x00\x42\x11\n\x0fviewOnceContent\x1a\xa6\x01\n\x12GroupInviteMessage\x12\x10\n\x08groupJID\x18\x01 \x01(\t\x12\x12\n\ninviteCode\x18\x02 \x01(\t\x12\x18\n\x10inviteExpiration\x18\x03 \x01(\x03\x12\x11\n\tgroupName\x18\x04 \x01(\t\x12\x15\n\rJPEGThumbnail\x18\x05 \x01(\x0c\x12&\n\x07\x63\x61ption\x18\x06 \x01(\x0b\x32\x15.WACommon.MessageText\x1a\x89\x02\n\x13LiveLocationMessage\x12\x45\n\x08location\x18\x01 \x01(\x0b\x32\x33.WAConsumerApplication.ConsumerApplication.Location\x12\x18\n\x10\x61\x63\x63uracyInMeters\x18\x02 \x01(\r\x12\x12\n\nspeedInMps\x18\x03 \x01(\x02\x12)\n!degreesClockwiseFromMagneticNorth\x18\x04 \x01(\r\x12&\n\x07\x63\x61ption\x18\x05 \x01(\x0b\x32\x15.WACommon.MessageText\x12\x16\n\x0esequenceNumber\x18\x06 \x01(\x03\x12\x12\n\ntimeOffset\x18\x07 \x01(\r\x1ax\n\x14\x43ontactsArrayMessage\x12\x13\n\x0b\x64isplayName\x18\x01 \x01(\t\x12K\n\x08\x63ontacts\x18\x02 \x03(\x0b\x32\x39.WAConsumerApplication.ConsumerApplication.ContactMessage\x1a\x38\n\x0e\x43ontactMessage\x12&\n\x07\x63ontact\x18\x01 \x01(\x0b\x32\x15.WACommon.SubProtocol\x1a\xd6\x02\n\x10StatusTextMesage\x12L\n\x04text\x18\x01 \x01(\x0b\x32>.WAConsumerApplication.ConsumerApplication.ExtendedTextMessage\x12\x10\n\x08textArgb\x18\x06 \x01(\x07\x12\x16\n\x0e\x62\x61\x63kgroundArgb\x18\x07 \x01(\x07\x12R\n\x04\x66ont\x18\x08 \x01(\x0e\x32\x44.WAConsumerApplication.ConsumerApplication.StatusTextMesage.FontType"v\n\x08\x46ontType\x12\x0e\n\nSANS_SERIF\x10\x00\x12\t\n\x05SERIF\x10\x01\x12\x13\n\x0fNORICAN_REGULAR\x10\x02\x12\x11\n\rBRYNDAN_WRITE\x10\x03\x12\x15\n\x11\x42\x45\x42\x41SNEUE_REGULAR\x10\x04\x12\x10\n\x0cOSWALD_HEAVY\x10\x05\x1a\xb8\x02\n\x13\x45xtendedTextMessage\x12#\n\x04text\x18\x01 \x01(\x0b\x32\x15.WACommon.MessageText\x12\x13\n\x0bmatchedText\x18\x02 \x01(\t\x12\x14\n\x0c\x63\x61nonicalURL\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\r\n\x05title\x18\x05 \x01(\t\x12(\n\tthumbnail\x18\x06 \x01(\x0b\x32\x15.WACommon.SubProtocol\x12_\n\x0bpreviewType\x18\x07 \x01(\x0e\x32J.WAConsumerApplication.ConsumerApplication.ExtendedTextMessage.PreviewType""\n\x0bPreviewType\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05VIDEO\x10\x01\x1ai\n\x0fLocationMessage\x12\x45\n\x08location\x18\x01 \x01(\x0b\x32\x33.WAConsumerApplication.ConsumerApplication.Location\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x1a\x38\n\x0eStickerMessage\x12&\n\x07sticker\x18\x01 \x01(\x0b\x32\x15.WACommon.SubProtocol\x1aL\n\x0f\x44ocumentMessage\x12\'\n\x08\x64ocument\x18\x01 \x01(\x0b\x32\x15.WACommon.SubProtocol\x12\x10\n\x08\x66ileName\x18\x02 \x01(\t\x1a\\\n\x0cVideoMessage\x12$\n\x05video\x18\x01 \x01(\x0b\x32\x15.WACommon.SubProtocol\x12&\n\x07\x63\x61ption\x18\x02 \x01(\x0b\x32\x15.WACommon.MessageText\x1a\x41\n\x0c\x41udioMessage\x12$\n\x05\x61udio\x18\x01 \x01(\x0b\x32\x15.WACommon.SubProtocol\x12\x0b\n\x03PTT\x18\x02 \x01(\x08\x1a\\\n\x0cImageMessage\x12$\n\x05image\x18\x01 \x01(\x0b\x32\x15.WACommon.SubProtocol\x12&\n\x07\x63\x61ption\x18\x02 \x01(\x0b\x32\x15.WACommon.MessageText\x1a\xb5\x01\n\x15InteractiveAnnotation\x12G\n\x08location\x18\x02 \x01(\x0b\x32\x33.WAConsumerApplication.ConsumerApplication.LocationH\x00\x12I\n\x0fpolygonVertices\x18\x01 \x03(\x0b\x32\x30.WAConsumerApplication.ConsumerApplication.PointB\x08\n\x06\x61\x63tion\x1a\x1d\n\x05Point\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\x1aK\n\x08Location\x12\x17\n\x0f\x64\x65greesLatitude\x18\x01 \x01(\x01\x12\x18\n\x10\x64\x65greesLongitude\x18\x02 \x01(\x01\x12\x0c\n\x04name\x18\x03 \x01(\t\x1a\x37\n\x0cMediaPayload\x12\'\n\x08protocol\x18\x01 \x01(\x0b\x32\x15.WACommon.SubProtocolB1Z/go.mau.fi/whatsmeow/proto/waConsumerApplication'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "waConsumerApplication.WAConsumerApplication_pb2", _globals
)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"Z/go.mau.fi/whatsmeow/proto/waConsumerApplication"
    _globals["_CONSUMERAPPLICATION"]._serialized_start = 102
    _globals["_CONSUMERAPPLICATION"]._serialized_end = 5808
    _globals["_CONSUMERAPPLICATION_PAYLOAD"]._serialized_start = 266
    _globals["_CONSUMERAPPLICATION_PAYLOAD"]._serialized_end = 599
    _globals["_CONSUMERAPPLICATION_SUBPROTOCOLPAYLOAD"]._serialized_start = 601
    _globals["_CONSUMERAPPLICATION_SUBPROTOCOLPAYLOAD"]._serialized_end = 673
    _globals["_CONSUMERAPPLICATION_METADATA"]._serialized_start = 676
    _globals["_CONSUMERAPPLICATION_METADATA"]._serialized_end = 833
    _globals["_CONSUMERAPPLICATION_METADATA_SPECIALTEXTSIZE"]._serialized_start = 782
    _globals["_CONSUMERAPPLICATION_METADATA_SPECIALTEXTSIZE"]._serialized_end = 833
    _globals["_CONSUMERAPPLICATION_SIGNAL"]._serialized_start = 835
    _globals["_CONSUMERAPPLICATION_SIGNAL"]._serialized_end = 843
    _globals["_CONSUMERAPPLICATION_APPLICATIONDATA"]._serialized_start = 845
    _globals["_CONSUMERAPPLICATION_APPLICATIONDATA"]._serialized_end = 960
    _globals["_CONSUMERAPPLICATION_CONTENT"]._serialized_start = 963
    _globals["_CONSUMERAPPLICATION_CONTENT"]._serialized_end = 2525
    _globals["_CONSUMERAPPLICATION_EDITMESSAGE"]._serialized_start = 2527
    _globals["_CONSUMERAPPLICATION_EDITMESSAGE"]._serialized_end = 2636
    _globals["_CONSUMERAPPLICATION_POLLADDOPTIONMESSAGE"]._serialized_start = 2638
    _globals["_CONSUMERAPPLICATION_POLLADDOPTIONMESSAGE"]._serialized_end = 2731
    _globals["_CONSUMERAPPLICATION_POLLVOTEMESSAGE"]._serialized_start = 2733
    _globals["_CONSUMERAPPLICATION_POLLVOTEMESSAGE"]._serialized_end = 2802
    _globals["_CONSUMERAPPLICATION_POLLENCVALUE"]._serialized_start = 2804
    _globals["_CONSUMERAPPLICATION_POLLENCVALUE"]._serialized_end = 2853
    _globals["_CONSUMERAPPLICATION_POLLUPDATEMESSAGE"]._serialized_start = 2856
    _globals["_CONSUMERAPPLICATION_POLLUPDATEMESSAGE"]._serialized_end = 3076
    _globals["_CONSUMERAPPLICATION_POLLCREATIONMESSAGE"]._serialized_start = 3079
    _globals["_CONSUMERAPPLICATION_POLLCREATIONMESSAGE"]._serialized_end = 3230
    _globals["_CONSUMERAPPLICATION_OPTION"]._serialized_start = 3232
    _globals["_CONSUMERAPPLICATION_OPTION"]._serialized_end = 3260
    _globals["_CONSUMERAPPLICATION_REACTIONMESSAGE"]._serialized_start = 3263
    _globals["_CONSUMERAPPLICATION_REACTIONMESSAGE"]._serialized_end = 3431
    _globals["_CONSUMERAPPLICATION_REVOKEMESSAGE"]._serialized_start = 3433
    _globals["_CONSUMERAPPLICATION_REVOKEMESSAGE"]._serialized_end = 3483
    _globals["_CONSUMERAPPLICATION_VIEWONCEMESSAGE"]._serialized_start = 3486
    _globals["_CONSUMERAPPLICATION_VIEWONCEMESSAGE"]._serialized_end = 3684
    _globals["_CONSUMERAPPLICATION_GROUPINVITEMESSAGE"]._serialized_start = 3687
    _globals["_CONSUMERAPPLICATION_GROUPINVITEMESSAGE"]._serialized_end = 3853
    _globals["_CONSUMERAPPLICATION_LIVELOCATIONMESSAGE"]._serialized_start = 3856
    _globals["_CONSUMERAPPLICATION_LIVELOCATIONMESSAGE"]._serialized_end = 4121
    _globals["_CONSUMERAPPLICATION_CONTACTSARRAYMESSAGE"]._serialized_start = 4123
    _globals["_CONSUMERAPPLICATION_CONTACTSARRAYMESSAGE"]._serialized_end = 4243
    _globals["_CONSUMERAPPLICATION_CONTACTMESSAGE"]._serialized_start = 4245
    _globals["_CONSUMERAPPLICATION_CONTACTMESSAGE"]._serialized_end = 4301
    _globals["_CONSUMERAPPLICATION_STATUSTEXTMESAGE"]._serialized_start = 4304
    _globals["_CONSUMERAPPLICATION_STATUSTEXTMESAGE"]._serialized_end = 4646
    _globals["_CONSUMERAPPLICATION_STATUSTEXTMESAGE_FONTTYPE"]._serialized_start = 4528
    _globals["_CONSUMERAPPLICATION_STATUSTEXTMESAGE_FONTTYPE"]._serialized_end = 4646
    _globals["_CONSUMERAPPLICATION_EXTENDEDTEXTMESSAGE"]._serialized_start = 4649
    _globals["_CONSUMERAPPLICATION_EXTENDEDTEXTMESSAGE"]._serialized_end = 4961
    _globals[
        "_CONSUMERAPPLICATION_EXTENDEDTEXTMESSAGE_PREVIEWTYPE"
    ]._serialized_start = 4927
    _globals[
        "_CONSUMERAPPLICATION_EXTENDEDTEXTMESSAGE_PREVIEWTYPE"
    ]._serialized_end = 4961
    _globals["_CONSUMERAPPLICATION_LOCATIONMESSAGE"]._serialized_start = 4963
    _globals["_CONSUMERAPPLICATION_LOCATIONMESSAGE"]._serialized_end = 5068
    _globals["_CONSUMERAPPLICATION_STICKERMESSAGE"]._serialized_start = 5070
    _globals["_CONSUMERAPPLICATION_STICKERMESSAGE"]._serialized_end = 5126
    _globals["_CONSUMERAPPLICATION_DOCUMENTMESSAGE"]._serialized_start = 5128
    _globals["_CONSUMERAPPLICATION_DOCUMENTMESSAGE"]._serialized_end = 5204
    _globals["_CONSUMERAPPLICATION_VIDEOMESSAGE"]._serialized_start = 5206
    _globals["_CONSUMERAPPLICATION_VIDEOMESSAGE"]._serialized_end = 5298
    _globals["_CONSUMERAPPLICATION_AUDIOMESSAGE"]._serialized_start = 5300
    _globals["_CONSUMERAPPLICATION_AUDIOMESSAGE"]._serialized_end = 5365
    _globals["_CONSUMERAPPLICATION_IMAGEMESSAGE"]._serialized_start = 5367
    _globals["_CONSUMERAPPLICATION_IMAGEMESSAGE"]._serialized_end = 5459
    _globals["_CONSUMERAPPLICATION_INTERACTIVEANNOTATION"]._serialized_start = 5462
    _globals["_CONSUMERAPPLICATION_INTERACTIVEANNOTATION"]._serialized_end = 5643
    _globals["_CONSUMERAPPLICATION_POINT"]._serialized_start = 5645
    _globals["_CONSUMERAPPLICATION_POINT"]._serialized_end = 5674
    _globals["_CONSUMERAPPLICATION_LOCATION"]._serialized_start = 5676
    _globals["_CONSUMERAPPLICATION_LOCATION"]._serialized_end = 5751
    _globals["_CONSUMERAPPLICATION_MEDIAPAYLOAD"]._serialized_start = 5753
    _globals["_CONSUMERAPPLICATION_MEDIAPAYLOAD"]._serialized_end = 5808
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: waSyncAction/WASyncAction.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from waChatLockSettings import (
    WAProtobufsChatLockSettings_pb2 as waChatLockSettings_dot_WAProtobufsChatLockSettings__pb2,
)
from waDeviceCapabilities import (
    WAProtobufsDeviceCapabilities_pb2 as waDeviceCapabilities_dot_WAProtobufsDeviceCapabilities__pb2,
)
from waCommon import WACommon_pb2 as waCommon_dot_WACommon__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1fwaSyncAction/WASyncAction.proto\x12\x0cWASyncAction\x1a\x34waChatLockSettings/WAProtobufsChatLockSettings.proto\x1a\x38waDeviceCapabilities/WAProtobufsDeviceCapabilities.proto\x1a\x17waCommon/WACommon.proto"\xfa\x06\n\rCallLogRecord\x12:\n\ncallResult\x18\x01 \x01(\x0e\x32&.WASyncAction.CallLogRecord.CallResult\x12\x11\n\tisDndMode\x18\x02 \x01(\x08\x12@\n\rsilenceReason\x18\x03 \x01(\x0e\x32).WASyncAction.CallLogRecord.SilenceReason\x12\x10\n\x08\x64uration\x18\x04 \x01(\x03\x12\x11\n\tstartTime\x18\x05 \x01(\x03\x12\x12\n\nisIncoming\x18\x06 \x01(\x08\x12\x0f\n\x07isVideo\x18\x07 \x01(\x08\x12\x12\n\nisCallLink\x18\x08 \x01(\x08\x12\x15\n\rcallLinkToken\x18\t \x01(\t\x12\x17\n\x0fscheduledCallID\x18\n \x01(\t\x12\x0e\n\x06\x63\x61llID\x18\x0b \x01(\t\x12\x16\n\x0e\x63\x61llCreatorJID\x18\x0c \x01(\t\x12\x10\n\x08groupJID\x18\r \x01(\t\x12\x41\n\x0cparticipants\x18\x0e \x03(\x0b\x32+.WASyncAction.CallLogRecord.ParticipantInfo\x12\x36\n\x08\x63\x61llType\x18\x0f \x01(\x0e\x32$.WASyncAction.CallLogRecord.CallType\x1a^\n\x0fParticipantInfo\x12\x0f\n\x07userJID\x18\x01 \x01(\t\x12:\n\ncallResult\x18\x02 \x01(\x0e\x32&.WASyncAction.CallLogRecord.CallResult";\n\x08\x43\x61llType\x12\x0b\n\x07REGULAR\x10\x00\x12\x12\n\x0eSCHEDULED_CALL\x10\x01\x12\x0e\n\nVOICE_CHAT\x10\x02"F\n\rSilenceReason\x12\x08\n\x04NONE\x10\x00\x12\r\n\tSCHEDULED\x10\x01\x12\x0b\n\x07PRIVACY\x10\x02\x12\x0f\n\x0bLIGHTWEIGHT\x10\x03"\xaf\x01\n\nCallResult\x12\r\n\tCONNECTED\x10\x00\x12\x0c\n\x08REJECTED\x10\x01\x12\r\n\tCANCELLED\x10\x02\x12\x15\n\x11\x41\x43\x43\x45PTEDELSEWHERE\x10\x03\x12\n\n\x06MISSED\x10\x04\x12\x0b\n\x07INVALID\x10\x05\x12\x0f\n\x0bUNAVAILABLE\x10\x06\x12\x0c\n\x08UPCOMING\x10\x07\x12\n\n\x06\x46\x41ILED\x10\x08\x12\r\n\tABANDONED\x10\t\x12\x0b\n\x07ONGOING\x10\n"\x8e\x01\n\x1cWaffleAccountLinkStateAction\x12N\n\tlinkState\x18\x02 \x01(\x0e\x32;.WASyncAction.WaffleAccountLinkStateAction.AccountLinkState"\x1e\n\x10\x41\x63\x63ountLinkState\x12\n\n\x06\x41\x43TIVE\x10\x00"\xc1\x01\n\x1cMerchantPaymentPartnerAction\x12\x41\n\x06status\x18\x01 \x02(\x0e\x32\x31.WASyncAction.MerchantPaymentPartnerAction.Status\x12\x0f\n\x07\x63ountry\x18\x02 \x02(\t\x12\x13\n\x0bgatewayName\x18\x03 \x01(\t\x12\x14\n\x0c\x63redentialID\x18\x04 \x01(\t""\n\x06Status\x12\n\n\x06\x41\x43TIVE\x10\x00\x12\x0c\n\x08INACTIVE\x10\x01"\xc5\x01\n\x0eNoteEditAction\x12\x33\n\x04type\x18\x01 \x01(\x0e\x32%.WASyncAction.NoteEditAction.NoteType\x12\x0f\n\x07\x63hatJID\x18\x02 \x01(\t\x12\x11\n\tcreatedAt\x18\x03 \x01(\x03\x12\x0f\n\x07\x64\x65leted\x18\x04 \x01(\x08\x12\x1b\n\x13unstructuredContent\x18\x05 \x01(\t",\n\x08NoteType\x12\x10\n\x0cUNSTRUCTURED\x10\x01\x12\x0e\n\nSTRUCTURED\x10\x02"\xb5\x01\n\x13StatusPrivacyAction\x12\x46\n\x04mode\x18\x01 \x01(\x0e\x32\x38.WASyncAction.StatusPrivacyAction.StatusDistributionMode\x12\x0f\n\x07userJID\x18\x02 \x03(\t"E\n\x16StatusDistributionMode\x12\x0e\n\nALLOW_LIST\x10\x00\x12\r\n\tDENY_LIST\x10\x01\x12\x0c\n\x08\x43ONTACTS\x10\x02"\x87\x02\n\x16MarketingMessageAction\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12P\n\x04type\x18\x03 \x01(\x0e\x32\x42.WASyncAction.MarketingMessageAction.MarketingMessagePrototypeType\x12\x11\n\tcreatedAt\x18\x04 \x01(\x03\x12\x12\n\nlastSentAt\x18\x05 \x01(\x03\x12\x11\n\tisDeleted\x18\x06 \x01(\x08\x12\x0f\n\x07mediaID\x18\x07 \x01(\t"1\n\x1dMarketingMessagePrototypeType\x12\x10\n\x0cPERSONALIZED\x10\x00"\x8f\x01\n\x1bUsernameChatStartModeAction\x12N\n\rchatStartMode\x18\x01 \x01(\x0e\x32\x37.WASyncAction.UsernameChatStartModeAction.ChatStartMode" \n\rChatStartMode\x12\x07\n\x03LID\x10\x01\x12\x06\n\x02PN\x10\x02"\x8a\x02\n\x0fLabelEditAction\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x63olor\x18\x02 \x01(\x05\x12\x14\n\x0cpredefinedID\x18\x03 \x01(\x05\x12\x0f\n\x07\x64\x65leted\x18\x04 \x01(\x08\x12\x12\n\norderIndex\x18\x05 \x01(\x05\x12\x10\n\x08isActive\x18\x06 \x01(\x08\x12\x34\n\x04type\x18\x07 \x01(\x0e\x32&.WASyncAction.LabelEditAction.ListType"W\n\x08ListType\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06UNREAD\x10\x01\x12\n\n\x06GROUPS\x10\x02\x12\r\n\tFAVORITES\x10\x03\x12\x0e\n\nPREDEFINED\x10\x04\x12\n\n\x06\x43USTOM\x10\x05"\xa4\x03\n\x0ePatchDebugData\x12\x15\n\rcurrentLthash\x18\x01 \x01(\x0c\x12\x11\n\tnewLthash\x18\x02 \x01(\x0c\x12\x14\n\x0cpatchVersion\x18\x03 \x01(\x0c\x12\x16\n\x0e\x63ollectionName\x18\x04 \x01(\x0c\x12/\n\'firstFourBytesFromAHashOfSnapshotMACKey\x18\x05 \x01(\x0c\x12\x19\n\x11newLthashSubtract\x18\x06 \x01(\x0c\x12\x11\n\tnumberAdd\x18\x07 \x01(\x05\x12\x14\n\x0cnumberRemove\x18\x08 \x01(\x05\x12\x16\n\x0enumberOverride\x18\t \x01(\x05\x12=\n\x0esenderPlatform\x18\n \x01(\x0e\x32%.WASyncAction.PatchDebugData.Platform\x12\x17\n\x0fisSenderPrimary\x18\x0b \x01(\x08"U\n\x08Platform\x12\x0b\n\x07\x41NDROID\x10\x00\x12\x08\n\x04SMBA\x10\x01\x12\n\n\x06IPHONE\x10\x02\x12\x08\n\x04SMBI\x10\x03\x12\x07\n\x03WEB\x10\x04\x12\x07\n\x03UWP\x10\x05\x12\n\n\x06\x44\x41RWIN\x10\x06"2\n\x11RecentEmojiWeight\x12\r\n\x05\x65moji\x18\x01 \x01(\t\x12\x0e\n\x06weight\x18\x02 \x01(\x02"\xd8\x1a\n\x0fSyncActionValue\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\x12,\n\nstarAction\x18\x02 \x01(\x0b\x32\x18.WASyncAction.StarAction\x12\x32\n\rcontactAction\x18\x03 \x01(\x0b\x32\x1b.WASyncAction.ContactAction\x12,\n\nmuteAction\x18\x04 \x01(\x0b\x32\x18.WASyncAction.MuteAction\x12*\n\tpinAction\x18\x05 \x01(\x0b\x32\x17.WASyncAction.PinAction\x12N\n\x1bsecurityNotificationSetting\x18\x06 \x01(\x0b\x32).WASyncAction.SecurityNotificationSetting\x12\x36\n\x0fpushNameSetting\x18\x07 \x01(\x0b\x32\x1d.WASyncAction.PushNameSetting\x12\x38\n\x10quickReplyAction\x18\x08 \x01(\x0b\x32\x1e.WASyncAction.QuickReplyAction\x12H\n\x18recentEmojiWeightsAction\x18\x0b \x01(\x0b\x32&.WASyncAction.RecentEmojiWeightsAction\x12\x36\n\x0flabelEditAction\x18\x0e \x01(\x0b\x32\x1d.WASyncAction.LabelEditAction\x12\x44\n\x16labelAssociationAction\x18\x0f \x01(\x0b\x32$.WASyncAction.LabelAssociationAction\x12\x32\n\rlocaleSetting\x18\x10 \x01(\x0b\x32\x1b.WASyncAction.LocaleSetting\x12:\n\x11\x61rchiveChatAction\x18\x11 \x01(\x0b\x32\x1f.WASyncAction.ArchiveChatAction\x12H\n\x18\x64\x65leteMessageForMeAction\x18\x12 \x01(\x0b\x32&.WASyncAction.DeleteMessageForMeAction\x12\x32\n\rkeyExpiration\x18\x13 \x01(\x0b\x32\x1b.WASyncAction.KeyExpiration\x12@\n\x14markChatAsReadAction\x18\x14 \x01(\x0b\x32".WASyncAction.MarkChatAsReadAction\x12\x36\n\x0f\x63learChatAction\x18\x15 \x01(\x0b\x32\x1d.WASyncAction.ClearChatAction\x12\x38\n\x10\x64\x65leteChatAction\x18\x16 \x01(\x0b\x32\x1e.WASyncAction.DeleteChatAction\x12\x42\n\x15unarchiveChatsSetting\x18\x17 \x01(\x0b\x32#.WASyncAction.UnarchiveChatsSetting\x12\x34\n\x0eprimaryFeature\x18\x18 \x01(\x0b\x32\x1c.WASyncAction.PrimaryFeature\x12J\n\x19\x61ndroidUnsupportedActions\x18\x1a \x01(\x0b\x32\'.WASyncAction.AndroidUnsupportedActions\x12.\n\x0b\x61gentAction\x18\x1b \x01(\x0b\x32\x19.WASyncAction.AgentAction\x12<\n\x12subscriptionAction\x18\x1c \x01(\x0b\x32 .WASyncAction.SubscriptionAction\x12@\n\x14userStatusMuteAction\x18\x1d \x01(\x0b\x32".WASyncAction.UserStatusMuteAction\x12\x38\n\x10timeFormatAction\x18\x1e \x01(\x0b\x32\x1e.WASyncAction.TimeFormatAction\x12*\n\tnuxAction\x18\x1f \x01(\x0b\x32\x17.WASyncAction.NuxAction\x12@\n\x14primaryVersionAction\x18  \x01(\x0b\x32".WASyncAction.PrimaryVersionAction\x12\x32\n\rstickerAction\x18! \x01(\x0b\x32\x1b.WASyncAction.StickerAction\x12J\n\x19removeRecentStickerAction\x18" \x01(\x0b\x32\'.WASyncAction.RemoveRecentStickerAction\x12:\n\x0e\x63hatAssignment\x18# \x01(\x0b\x32".WASyncAction.ChatAssignmentAction\x12R\n\x1a\x63hatAssignmentOpenedStatus\x18$ \x01(\x0b\x32..WASyncAction.ChatAssignmentOpenedStatusAction\x12<\n\x12pnForLidChatAction\x18% \x01(\x0b\x32 .WASyncAction.PnForLidChatAction\x12\x44\n\x16marketingMessageAction\x18& \x01(\x0b\x32$.WASyncAction.MarketingMessageAction\x12V\n\x1fmarketingMessageBroadcastAction\x18\' \x01(\x0b\x32-.WASyncAction.MarketingMessageBroadcastAction\x12\x42\n\x15\x65xternalWebBetaAction\x18( \x01(\x0b\x32#.WASyncAction.ExternalWebBetaAction\x12N\n\x1bprivacySettingRelayAllCalls\x18) \x01(\x0b\x32).WASyncAction.PrivacySettingRelayAllCalls\x12\x32\n\rcallLogAction\x18* \x01(\x0b\x32\x1b.WASyncAction.CallLogAction\x12\x38\n\rstatusPrivacy\x18, \x01(\x0b\x32!.WASyncAction.StatusPrivacyAction\x12\x46\n\x17\x62otWelcomeRequestAction\x18- \x01(\x0b\x32%.WASyncAction.BotWelcomeRequestAction\x12L\n\x17\x64\x65leteIndividualCallLog\x18. \x01(\x0b\x32+.WASyncAction.DeleteIndividualCallLogAction\x12\x42\n\x15labelReorderingAction\x18/ \x01(\x0b\x32#.WASyncAction.LabelReorderingAction\x12:\n\x11paymentInfoAction\x18\x30 \x01(\x0b\x32\x1f.WASyncAction.PaymentInfoAction\x12L\n\x1a\x63ustomPaymentMethodsAction\x18\x31 \x01(\x0b\x32(.WASyncAction.CustomPaymentMethodsAction\x12\x34\n\x0elockChatAction\x18\x32 \x01(\x0b\x32\x1c.WASyncAction.LockChatAction\x12G\n\x10\x63hatLockSettings\x18\x33 \x01(\x0b\x32-.WAProtobufsChatLockSettings.ChatLockSettings\x12H\n\x18wamoUserIdentifierAction\x18\x34 \x01(\x0b\x32&.WASyncAction.WamoUserIdentifierAction\x12\x66\n\'privacySettingDisableLinkPreviewsAction\x18\x35 \x01(\x0b\x32\x35.WASyncAction.PrivacySettingDisableLinkPreviewsAction\x12M\n\x12\x64\x65viceCapabilities\x18\x36 \x01(\x0b\x32\x31.WAProtobufsDeviceCapabilities.DeviceCapabilities\x12\x34\n\x0enoteEditAction\x18\x37 \x01(\x0b\x32\x1c.WASyncAction.NoteEditAction\x12\x36\n\x0f\x66\x61voritesAction\x18\x38 \x01(\x0b\x32\x1d.WASyncAction.FavoritesAction\x12P\n\x1cmerchantPaymentPartnerAction\x18\x39 \x01(\x0b\x32*.WASyncAction.MerchantPaymentPartnerAction\x12P\n\x1cwaffleAccountLinkStateAction\x18: \x01(\x0b\x32*.WASyncAction.WaffleAccountLinkStateAction\x12H\n\x15usernameChatStartMode\x18; \x01(\x0b\x32).WASyncAction.UsernameChatStartModeAction"d\n\x0f\x46\x61voritesAction\x12\x39\n\tfavorites\x18\x01 \x03(\x0b\x32&.WASyncAction.FavoritesAction.Favorite\x1a\x16\n\x08\x46\x61vorite\x12\n\n\x02ID\x18\x01 \x01(\t"E\n\'PrivacySettingDisableLinkPreviewsAction\x12\x1a\n\x12isPreviewsDisabled\x18\x01 \x01(\x08".\n\x18WamoUserIdentifierAction\x12\x12\n\nidentifier\x18\x01 \x01(\t" \n\x0eLockChatAction\x12\x0e\n\x06locked\x18\x01 \x01(\x08"]\n\x1a\x43ustomPaymentMethodsAction\x12?\n\x14\x63ustomPaymentMethods\x18\x01 \x03(\x0b\x32!.WASyncAction.CustomPaymentMethod"\x87\x01\n\x13\x43ustomPaymentMethod\x12\x14\n\x0c\x63redentialID\x18\x01 \x02(\t\x12\x0f\n\x07\x63ountry\x18\x02 \x02(\t\x12\x0c\n\x04type\x18\x03 \x02(\t\x12;\n\x08metadata\x18\x04 \x03(\x0b\x32).WASyncAction.CustomPaymentMethodMetadata"9\n\x1b\x43ustomPaymentMethodMetadata\x12\x0b\n\x03key\x18\x01 \x02(\t\x12\r\n\x05value\x18\x02 \x02(\t" \n\x11PaymentInfoAction\x12\x0b\n\x03\x63pi\x18\x01 \x01(\t"/\n\x15LabelReorderingAction\x12\x16\n\x0esortedLabelIDs\x18\x01 \x03(\x05"D\n\x1d\x44\x65leteIndividualCallLogAction\x12\x0f\n\x07peerJID\x18\x01 \x01(\t\x12\x12\n\nisIncoming\x18\x02 \x01(\x08")\n\x17\x42otWelcomeRequestAction\x12\x0e\n\x06isSent\x18\x01 \x01(\x08"C\n\rCallLogAction\x12\x32\n\rcallLogRecord\x18\x01 \x01(\x0b\x32\x1b.WASyncAction.CallLogRecord"0\n\x1bPrivacySettingRelayAllCalls\x12\x11\n\tisEnabled\x18\x01 \x01(\x08"(\n\x15\x45xternalWebBetaAction\x12\x0f\n\x07isOptIn\x18\x01 \x01(\x08"7\n\x1fMarketingMessageBroadcastAction\x12\x14\n\x0crepliedCount\x18\x01 \x01(\x05"#\n\x12PnForLidChatAction\x12\r\n\x05pnJID\x18\x01 \x01(\t"6\n ChatAssignmentOpenedStatusAction\x12\x12\n\nchatOpened\x18\x01 \x01(\x08"-\n\x14\x43hatAssignmentAction\x12\x15\n\rdeviceAgentID\x18\x01 \x01(\t"\xda\x01\n\rStickerAction\x12\x0b\n\x03URL\x18\x01 \x01(\t\x12\x15\n\rfileEncSHA256\x18\x02 \x01(\x0c\x12\x10\n\x08mediaKey\x18\x03 \x01(\x0c\x12\x10\n\x08mimetype\x18\x04 \x01(\t\x12\x0e\n\x06height\x18\x05 \x01(\r\x12\r\n\x05width\x18\x06 \x01(\r\x12\x12\n\ndirectPath\x18\x07 \x01(\t\x12\x12\n\nfileLength\x18\x08 \x01(\x04\x12\x12\n\nisFavorite\x18\t \x01(\x08\x12\x14\n\x0c\x64\x65viceIDHint\x18\n \x01(\r\x12\x10\n\x08isLottie\x18\x0b \x01(\x08"6\n\x19RemoveRecentStickerAction\x12\x19\n\x11lastStickerSentTS\x18\x01 \x01(\x03"\'\n\x14PrimaryVersionAction\x12\x0f\n\x07version\x18\x01 \x01(\t"!\n\tNuxAction\x12\x14\n\x0c\x61\x63knowledged\x18\x01 \x01(\x08"9\n\x10TimeFormatAction\x12%\n\x1disTwentyFourHourFormatEnabled\x18\x01 \x01(\x08"%\n\x14UserStatusMuteAction\x12\r\n\x05muted\x18\x01 \x01(\x08"[\n\x12SubscriptionAction\x12\x15\n\risDeactivated\x18\x01 \x01(\x08\x12\x16\n\x0eisAutoRenewing\x18\x02 \x01(\x08\x12\x16\n\x0e\x65xpirationDate\x18\x03 \x01(\x03"@\n\x0b\x41gentAction\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x64\x65viceID\x18\x02 \x01(\x05\x12\x11\n\tisDeleted\x18\x03 \x01(\x08",\n\x19\x41ndroidUnsupportedActions\x12\x0f\n\x07\x61llowed\x18\x01 \x01(\x08"\x1f\n\x0ePrimaryFeature\x12\r\n\x05\x66lags\x18\x01 \x03(\t"(\n\rKeyExpiration\x12\x17\n\x0f\x65xpiredKeyEpoch\x18\x01 \x01(\x05"I\n\x11SyncActionMessage\x12!\n\x03key\x18\x01 \x01(\x0b\x32\x14.WACommon.MessageKey\x12\x11\n\ttimestamp\x18\x02 \x01(\x03"\x8d\x01\n\x16SyncActionMessageRange\x12\x1c\n\x14lastMessageTimestamp\x18\x01 \x01(\x03\x12"\n\x1alastSystemMessageTimestamp\x18\x02 \x01(\x03\x12\x31\n\x08messages\x18\x03 \x03(\x0b\x32\x1f.WASyncAction.SyncActionMessage"/\n\x15UnarchiveChatsSetting\x12\x16\n\x0eunarchiveChats\x18\x01 \x01(\x08"N\n\x10\x44\x65leteChatAction\x12:\n\x0cmessageRange\x18\x01 \x01(\x0b\x32$.WASyncAction.SyncActionMessageRange"M\n\x0f\x43learChatAction\x12:\n\x0cmessageRange\x18\x01 \x01(\x0b\x32$.WASyncAction.SyncActionMessageRange"`\n\x14MarkChatAsReadAction\x12\x0c\n\x04read\x18\x01 \x01(\x08\x12:\n\x0cmessageRange\x18\x02 \x01(\x0b\x32$.WASyncAction.SyncActionMessageRange"I\n\x18\x44\x65leteMessageForMeAction\x12\x13\n\x0b\x64\x65leteMedia\x18\x01 \x01(\x08\x12\x18\n\x10messageTimestamp\x18\x02 \x01(\x03"a\n\x11\x41rchiveChatAction\x12\x10\n\x08\x61rchived\x18\x01 \x01(\x08\x12:\n\x0cmessageRange\x18\x02 \x01(\x0b\x32$.WASyncAction.SyncActionMessageRange"L\n\x18RecentEmojiWeightsAction\x12\x30\n\x07weights\x18\x01 \x03(\x0b\x32\x1f.WASyncAction.RecentEmojiWeight")\n\x16LabelAssociationAction\x12\x0f\n\x07labeled\x18\x01 \x01(\x08"g\n\x10QuickReplyAction\x12\x10\n\x08shortcut\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x10\n\x08keywords\x18\x03 \x03(\t\x12\r\n\x05\x63ount\x18\x04 \x01(\x05\x12\x0f\n\x07\x64\x65leted\x18\x05 \x01(\x08"\x1f\n\rLocaleSetting\x12\x0e\n\x06locale\x18\x01 \x01(\t"\x1f\n\x0fPushNameSetting\x12\x0c\n\x04name\x18\x01 \x01(\t"7\n\x1bSecurityNotificationSetting\x12\x18\n\x10showNotification\x18\x01 \x01(\x08"\x1b\n\tPinAction\x12\x0e\n\x06pinned\x18\x01 \x01(\x08"H\n\nMuteAction\x12\r\n\x05muted\x18\x01 \x01(\x08\x12\x18\n\x10muteEndTimestamp\x18\x02 \x01(\x03\x12\x11\n\tautoMuted\x18\x03 \x01(\x08"f\n\rContactAction\x12\x10\n\x08\x66ullName\x18\x01 \x01(\t\x12\x11\n\tfirstName\x18\x02 \x01(\t\x12\x0e\n\x06lidJID\x18\x03 \x01(\t\x12 \n\x18saveOnPrimaryAddressbook\x18\x04 \x01(\x08"\x1d\n\nStarAction\x12\x0f\n\x07starred\x18\x01 \x01(\x08"o\n\x0eSyncActionData\x12\r\n\x05index\x18\x01 \x01(\x0c\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x1d.WASyncAction.SyncActionValue\x12\x0f\n\x07padding\x18\x03 \x01(\x0c\x12\x0f\n\x07version\x18\x04 \x01(\x05\x42(Z&go.mau.fi/whatsmeow/proto/waSyncAction'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "waSyncAction.WASyncAction_pb2", _globals
)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"Z&go.mau.fi/whatsmeow/proto/waSyncAction"
    _globals["_CALLLOGRECORD"]._serialized_start = 187
    _globals["_CALLLOGRECORD"]._serialized_end = 1077
    _globals["_CALLLOGRECORD_PARTICIPANTINFO"]._serialized_start = 672
    _globals["_CALLLOGRECORD_PARTICIPANTINFO"]._serialized_end = 766
    _globals["_CALLLOGRECORD_CALLTYPE"]._serialized_start = 768
    _globals["_CALLLOGRECORD_CALLTYPE"]._serialized_end = 827
    _globals["_CALLLOGRECORD_SILENCEREASON"]._serialized_start = 829
    _globals["_CALLLOGRECORD_SILENCEREASON"]._serialized_end = 899
    _globals["_CALLLOGRECORD_CALLRESULT"]._serialized_start = 902
    _globals["_CALLLOGRECORD_CALLRESULT"]._serialized_end = 1077
    _globals["_WAFFLEACCOUNTLINKSTATEACTION"]._serialized_start = 1080
    _globals["_WAFFLEACCOUNTLINKSTATEACTION"]._serialized_end = 1222
    _globals["_WAFFLEACCOUNTLINKSTATEACTION_ACCOUNTLINKSTATE"]._serialized_start = 1192
    _globals["_WAFFLEACCOUNTLINKSTATEACTION_ACCOUNTLINKSTATE"]._serialized_end = 1222
    _globals["_MERCHANTPAYMENTPARTNERACTION"]._serialized_start = 1225
    _globals["_MERCHANTPAYMENTPARTNERACTION"]._serialized_end = 1418
    _globals["_MERCHANTPAYMENTPARTNERACTION_STATUS"]._serialized_start = 1384
    _globals["_MERCHANTPAYMENTPARTNERACTION_STATUS"]._serialized_end = 1418
    _globals["_NOTEEDITACTION"]._serialized_start = 1421
    _globals["_NOTEEDITACTION"]._serialized_end = 1618
    _globals["_NOTEEDITACTION_NOTETYPE"]._serialized_start = 1574
    _globals["_NOTEEDITACTION_NOTETYPE"]._serialized_end = 1618
    _globals["_STATUSPRIVACYACTION"]._serialized_start = 1621
    _globals["_STATUSPRIVACYACTION"]._serialized_end = 1802
    _globals["_STATUSPRIVACYACTION_STATUSDISTRIBUTIONMODE"]._serialized_start = 1733
    _globals["_STATUSPRIVACYACTION_STATUSDISTRIBUTIONMODE"]._serialized_end = 1802
    _globals["_MARKETINGMESSAGEACTION"]._serialized_start = 1805
    _globals["_MARKETINGMESSAGEACTION"]._serialized_end = 2068
    _globals[
        "_MARKETINGMESSAGEACTION_MARKETINGMESSAGEPROTOTYPETYPE"
    ]._serialized_start = 2019
    _globals[
        "_MARKETINGMESSAGEACTION_MARKETINGMESSAGEPROTOTYPETYPE"
    ]._serialized_end = 2068
    _globals["_USERNAMECHATSTARTMODEACTION"]._serialized_start = 2071
    _globals["_USERNAMECHATSTARTMODEACTION"]._serialized_end = 2214
    _globals["_USERNAMECHATSTARTMODEACTION_CHATSTARTMODE"]._serialized_start = 2182
    _globals["_USERNAMECHATSTARTMODEACTION_CHATSTARTMODE"]._serialized_end = 2214
    _globals["_LABELEDITACTION"]._serialized_start = 2217
    _globals["_LABELEDITACTION"]._serialized_end = 2483
    _globals["_LABELEDITACTION_LISTTYPE"]._serialized_start = 2396
    _globals["_LABELEDITACTION_LISTTYPE"]._serialized_end = 2483
    _globals["_PATCHDEBUGDATA"]._serialized_start = 2486
    _globals["_PATCHDEBUGDATA"]._serialized_end = 2906
    _globals["_PATCHDEBUGDATA_PLATFORM"]._serialized_start = 2821
    _globals["_PATCHDEBUGDATA_PLATFORM"]._serialized_end = 2906
    _globals["_RECENTEMOJIWEIGHT"]._serialized_start = 2908
    _globals["_RECENTEMOJIWEIGHT"]._serialized_end = 2958
    _globals["_SYNCACTIONVALUE"]._serialized_start = 2961
    _globals["_SYNCACTIONVALUE"]._serialized_end = 6377
    _globals["_FAVORITESACTION"]._serialized_start = 6379
    _globals["_FAVORITESACTION"]._serialized_end = 6479
    _globals["_FAVORITESACTION_FAVORITE"]._serialized_start = 6457
    _globals["_FAVORITESACTION_FAVORITE"]._serialized_end = 6479
    _globals["_PRIVACYSETTINGDISABLELINKPREVIEWSACTION"]._serialized_start = 6481
    _globals["_PRIVACYSETTINGDISABLELINKPREVIEWSACTION"]._serialized_end = 6550
    _globals["_WAMOUSERIDENTIFIERACTION"]._serialized_start = 6552
    _globals["_WAMOUSERIDENTIFIERACTION"]._serialized_end = 6598
    _globals["_LOCKCHATACTION"]._serialized_start = 6600
    _globals["_LOCKCHATACTION"]._serialized_end = 6632
    _globals["_CUSTOMPAYMENTMETHODSACTION"]._serialized_start = 6634
    _globals["_CUSTOMPAYMENTMETHODSACTION"]._serialized_end = 6727
    _globals["_CUSTOMPAYMENTMETHOD"]._serialized_start = 6730
    _globals["_CUSTOMPAYMENTMETHOD"]._serialized_end = 6865
    _globals["_CUSTOMPAYMENTMETHODMETADATA"]._serialized_start = 6867
    _globals["_CUSTOMPAYMENTMETHODMETADATA"]._serialized_end = 6924
    _globals["_PAYMENTINFOACTION"]._serialized_start = 6926
    _globals["_PAYMENTINFOACTION"]._serialized_end = 6958
    _globals["_LABELREORDERINGACTION"]._serialized_start = 6960
    _globals["_LABELREORDERINGACTION"]._serialized_end = 7007
    _globals["_DELETEINDIVIDUALCALLLOGACTION"]._serialized_start = 7009
    _globals["_DELETEINDIVIDUALCALLLOGACTION"]._serialized_end = 7077
    _globals["_BOTWELCOMEREQUESTACTION"]._serialized_start = 7079
    _globals["_BOTWELCOMEREQUESTACTION"]._serialized_end = 7120
    _globals["_CALLLOGACTION"]._serialized_start = 7122
    _globals["_CALLLOGACTION"]._serialized_end = 7189
    _globals["_PRIVACYSETTINGRELAYALLCALLS"]._serialized_start = 7191
    _globals["_PRIVACYSETTINGRELAYALLCALLS"]._serialized_end = 7239
    _globals["_EXTERNALWEBBETAACTION"]._serialized_start = 7241
    _globals["_EXTERNALWEBBETAACTION"]._serialized_end = 7281
    _globals["_MARKETINGMESSAGEBROADCASTACTION"]._serialized_start = 7283
    _globals["_MARKETINGMESSAGEBROADCASTACTION"]._serialized_end = 7338
    _globals["_PNFORLIDCHATACTION"]._serialized_start = 7340
    _globals["_PNFORLIDCHATACTION"]._serialized_end = 7375
    _globals["_CHATASSIGNMENTOPENEDSTATUSACTION"]._serialized_start = 7377
    _globals["_CHATASSIGNMENTOPENEDSTATUSACTION"]._serialized_end = 7431
    _globals["_CHATASSIGNMENTACTION"]._serialized_start = 7433
    _globals["_CHATASSIGNMENTACTION"]._serialized_end = 7478
    _globals["_STICKERACTION"]._serialized_start = 7481
    _globals["_STICKERACTION"]._serialized_end = 7699
    _globals["_REMOVERECENTSTICKERACTION"]._serialized_start = 7701
    _globals["_REMOVERECENTSTICKERACTION"]._serialized_end = 7755
    _globals["_PRIMARYVERSIONACTION"]._serialized_start = 7757
    _globals["_PRIMARYVERSIONACTION"]._serialized_end = 7796
    _globals["_NUXACTION"]._serialized_start = 7798
    _globals["_NUXACTION"]._serialized_end = 7831
    _globals["_TIMEFORMATACTION"]._serialized_start = 7833
    _globals["_TIMEFORMATACTION"]._serialized_end = 7890
    _globals["_USERSTATUSMUTEACTION"]._serialized_start = 7892
    _globals["_USERSTATUSMUTEACTION"]._serialized_end = 7929
    _globals["_SUBSCRIPTIONACTION"]._serialized_start = 7931
    _globals["_SUBSCRIPTIONACTION"]._serialized_end = 8022
    _globals["_AGENTACTION"]._serialized_start = 8024
    _globals["_AGENTACTION"]._serialized_end = 8088
    _globals["_ANDROIDUNSUPPORTEDACTIONS"]._serialized_start = 8090
    _globals["_ANDROIDUNSUPPORTEDACTIONS"]._serialized_end = 8134
    _globals["_PRIMARYFEATURE"]._serialized_start = 8136
    _globals["_PRIMARYFEATURE"]._serialized_end = 8167
    _globals["_KEYEXPIRATION"]._serialized_start = 8169
    _globals["_KEYEXPIRATION"]._serialized_end = 8209
    _globals["_SYNCACTIONMESSAGE"]._serialized_start = 8211
    _globals["_SYNCACTIONMESSAGE"]._serialized_end = 8284
    _globals["_SYNCACTIONMESSAGERANGE"]._serialized_start = 8287
    _globals["_SYNCACTIONMESSAGERANGE"]._serialized_end = 8428
    _globals["_UNARCHIVECHATSSETTING"]._serialized_start = 8430
    _globals["_UNARCHIVECHATSSETTING"]._serialized_end = 8477
    _globals["_DELETECHATACTION"]._serialized_start = 8479
    _globals["_DELETECHATACTION"]._serialized_end = 8557
    _globals["_CLEARCHATACTION"]._serialized_start = 8559
    _globals["_CLEARCHATACTION"]._serialized_end = 8636
    _globals["_MARKCHATASREADACTION"]._serialized_start = 8638
    _globals["_MARKCHATASREADACTION"]._serialized_end = 8734
    _globals["_DELETEMESSAGEFORMEACTION"]._serialized_start = 8736
    _globals["_DELETEMESSAGEFORMEACTION"]._serialized_end = 8809
    _globals["_ARCHIVECHATACTION"]._serialized_start = 8811
    _globals["_ARCHIVECHATACTION"]._serialized_end = 8908
    _globals["_RECENTEMOJIWEIGHTSACTION"]._serialized_start = 8910
    _globals["_RECENTEMOJIWEIGHTSACTION"]._serialized_end = 8986
    _globals["_LABELASSOCIATIONACTION"]._serialized_start = 8988
    _globals["_LABELASSOCIATIONACTION"]._serialized_end = 9029
    _globals["_QUICKREPLYACTION"]._serialized_start = 9031
    _globals["_QUICKREPLYACTION"]._serialized_end = 9134
    _globals["_LOCALESETTING"]._serialized_start = 9136
    _globals["_LOCALESETTING"]._serialized_end = 9167
    _globals["_PUSHNAMESETTING"]._serialized_start = 9169
    _globals["_PUSHNAMESETTING"]._serialized_end = 9200
    _globals["_SECURITYNOTIFICATIONSETTING"]._serialized_start = 9202
    _globals["_SECURITYNOTIFICATIONSETTING"]._serialized_end = 9257
    _globals["_PINACTION"]._serialized_start = 9259
    _globals["_PINACTION"]._serialized_end = 9286
    _globals["_MUTEACTION"]._serialized_start = 9288
    _globals["_MUTEACTION"]._serialized_end = 9360
    _globals["_CONTACTACTION"]._serialized_start = 9362
    _globals["_CONTACTACTION"]._serialized_end = 9464
    _globals["_STARACTION"]._serialized_start = 9466
    _globals["_STARACTION"]._serialized_end = 9495
    _globals["_SYNCACTIONDATA"]._serialized_start = 9497
    _globals["_SYNCACTIONDATA"]._serialized_end = 9608
# @@protoc_insertion_point(module_scope)
